@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: Shapes2Grid.h 911 2011-02-14 16:38:15Z reklov_w $
+ * Version $Id: Shapes2Grid.h 1130 2011-07-14 07:42:46Z reklov_w $
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -82,7 +82,7 @@
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-class CShapes2Grid : public CSG_Module  
+class grid_gridding_EXPORT CShapes2Grid : public CSG_Module  
 {
 public:
 	CShapes2Grid(void);
