@@ -1,3 +1,6 @@
+/**********************************************************
+ * Version $Id: Grid_Merge.cpp 911 2011-02-14 16:38:15Z reklov_w $
+ *********************************************************/
 
 ///////////////////////////////////////////////////////////
 //                                                       //
@@ -385,6 +388,7 @@ bool CGrid_Merge::On_Execute(void)
                         pMerged->Set_Value(x, y, pMerged->asDouble(x, y) / pCount->asInt(x, y));
                 }
             }
+			delete (pCount);
         }
 
 		return( true );
