@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: Grid_Value_Reclassify.h 911 2011-02-14 16:38:15Z reklov_w $
+ * Version $Id: Grid_Value_Reclassify.h 1122 2011-07-03 18:19:18Z reklov_w $
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -40,15 +40,13 @@
 //                                                       //
 //-------------------------------------------------------//
 //                                                       //
-//    e-mail:     volker.wichmann@ku-eichstaett.de       //
+//    e-mail:     wichmann@laserdata                     //
 //                                                       //
 //    contact:    Volker Wichmann                        //
-//                Research Associate                     //
-//                Chair of Physical Geography		     //
-//				  KU Eichstaett-Ingolstadt				 //
-//                Ostenstr. 18                           //
-//                85072 Eichstaett                       //
-//                Germany                                //
+//                LASERDATA GmbH                         //
+//                Management and analysis of             //
+//                laserscanning data                     //
+//                Innsbruck, Austria                     //
 //                                                       //
 ///////////////////////////////////////////////////////////
 
@@ -96,6 +94,7 @@ protected:
 
 	virtual bool			On_Execute		(void);
 
+	virtual int				On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter);
 
 private:
 
