@@ -1,3 +1,6 @@
+/**********************************************************
+ * Version $Id: Grid_Statistics_AddTo_Polygon.h 1025 2011-04-28 16:16:37Z oconrad $
+ *********************************************************/
 
 ///////////////////////////////////////////////////////////
 //                                                       //
@@ -61,29 +64,49 @@
 #ifndef HEADER_INCLUDED__Grid_Statistics_AddTo_Polygon_H
 #define HEADER_INCLUDED__Grid_Statistics_AddTo_Polygon_H
 
-//---------------------------------------------------------
 
+///////////////////////////////////////////////////////////
+//														 //
+//                                                       //
+//														 //
+///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 #include "MLB_Interface.h"
 
+
+///////////////////////////////////////////////////////////
+//														 //
+//                                                       //
+//														 //
+///////////////////////////////////////////////////////////
+
 //---------------------------------------------------------
 class CGrid_Statistics_AddTo_Polygon : public CSG_Module_Grid  
 {
 public:
 	CGrid_Statistics_AddTo_Polygon(void);
-	virtual ~CGrid_Statistics_AddTo_Polygon(void);
+
+	virtual const SG_Char *	Get_MenuPath	(void)	{	return( _TL("R:Grid Values") );	}
 
 
 protected:
 
-	virtual bool		On_Execute(void);
+	virtual bool			On_Execute		(void);
 
 
 private:
 
-	bool				Get_ShapeIDs(CSG_Shapes *pShapes, CSG_Grid *pShapeIDs);
+	bool					Get_ShapeIDs	(CSG_Shapes *pShapes, CSG_Grid *pShapeIDs);
 
 };
 
+
+///////////////////////////////////////////////////////////
+//														 //
+//                                                       //
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
 #endif // #ifndef HEADER_INCLUDED__Grid_Statistics_AddTo_Polygon_H
