@@ -1,3 +1,6 @@
+/**********************************************************
+ * Version $Id: QueryParser.h 911 2011-02-14 16:38:15Z reklov_w $
+ *********************************************************/
 /*******************************************************************************
     QueryParser.h
     Copyright (C) Victor Olaya
@@ -32,10 +35,12 @@ public:
 	virtual ~CQueryParser();
 	int& GetSelectedRecords();
 	int GetSelectedRecordsCount();
+	bool	is_Initialized();
 
 private:
 
-	std::vector <int> m_pSelectedRecords;
+	std::vector<int>	m_pSelectedRecords;
+	bool				m_bInit;
 
 };
 
