@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: kriging_base.h 911 2011-02-14 16:38:15Z reklov_w $
+ * Version $Id: kriging_base.h 1206 2011-10-28 11:54:29Z oconrad $
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -90,7 +90,7 @@ public:
 
 protected:
 
-	bool						m_bBlock;
+	bool						m_bBlock, m_bLog;
 
 	int							m_zField;
 
@@ -110,13 +110,14 @@ protected:
 	virtual bool				On_Execute				(void);
 
 	virtual int					On_Parameter_Changed	(CSG_Parameters *pParameters, CSG_Parameter *pParameter);
+	virtual int					On_Parameters_Enable	(CSG_Parameters *pParameters, CSG_Parameter *pParameter);
 
 	virtual bool				On_Initialise			(void)					{	return( true );	}
 
 	virtual bool				Get_Value				(double x, double y, double &z, double &Variance)	= 0;
 
-	double						Get_Weight				(double d)				{	return( m_Variogram.Get_Value(d) );	}
-	double						Get_Weight				(double dx, double dy)	{	return( m_Variogram.Get_Value(sqrt(dx*dx + dy*dy)) );	}
+	double						Get_Weight				(double d)				{	return( m_Model.Get_Value(d) );	}
+	double						Get_Weight				(double dx, double dy)	{	return( m_Model.Get_Value(sqrt(dx*dx + dy*dy)) );	}
 
 
 private:
@@ -125,9 +126,7 @@ private:
 
 	CSG_Parameters_Grid_Target	m_Grid_Target;
 
-	CSG_Table					m_Variances;
-
-	CSG_Trend					m_Variogram;
+	CSG_Trend					m_Model;
 
 	CSG_Grid					*m_pGrid, *m_pVariance;
 
@@ -138,8 +137,6 @@ private:
 
 	bool						_Interpolate			(void);
 
-	bool						_Get_Variances			(void);
-
 };
 
 
