@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: Flow_Parallel.cpp 1016 2011-04-27 18:40:36Z oconrad $
+ * Version $Id: Flow_Parallel.cpp 1081 2011-06-08 08:05:26Z reklov_w $
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -260,7 +260,7 @@ bool CFlow_Parallel::Calculate(int x, int y)
 //---------------------------------------------------------
 bool CFlow_Parallel::Set_Flow(void)
 {
-	int		n, x, y;
+	int		x, y;
 
 
 	double  THRS = 0.0;
@@ -283,7 +283,7 @@ bool CFlow_Parallel::Set_Flow(void)
 	}
 
 	//-----------------------------------------------------
-	for(n=0; n<Get_NCells() && Set_Progress_NCells(n); n++)
+	for(long n=0; n<Get_NCells() && Set_Progress_NCells(n); n++)
 	{
 		pDTM->Get_Sorted(n,x,y);
 
@@ -355,7 +355,7 @@ bool CFlow_Parallel::Set_Flow(void)
 	//-----------------------------------------------------
 	if( pRoute )
 	{
-		for(n=0; n<Get_NCells() && Set_Progress_NCells(n); n++)
+		for(long n=0; n<Get_NCells() && Set_Progress_NCells(n); n++)
 		{
 			pDTM->Get_Sorted(n, x, y, false);
 
