@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: api_file.cpp 1049 2011-05-09 07:55:38Z oconrad $
+ * Version $Id: api_file.cpp 1085 2011-06-08 08:11:35Z reklov_w $
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -169,7 +169,7 @@ bool CSG_File::Set_UnicodeFlag(bool bOn)
 }
 
 //---------------------------------------------------------
-int CSG_File::Length(void)	const
+long CSG_File::Length(void)	const
 {
 	if( m_pStream )
 	{
@@ -193,7 +193,7 @@ bool CSG_File::is_EOF(void)	const
 }
 
 //---------------------------------------------------------
-bool CSG_File::Seek(int Offset, int Origin) const
+bool CSG_File::Seek(long Offset, int Origin) const
 {
 	switch( Origin )
 	{
@@ -219,7 +219,7 @@ bool CSG_File::Seek_End(void) const
 }
 
 //---------------------------------------------------------
-int CSG_File::Tell(void) const
+long CSG_File::Tell(void) const
 {
 	return( m_pStream ? ftell(m_pStream) : -1 );
 }
