@@ -1,3 +1,6 @@
+/**********************************************************
+ * Version $Id: dataobject.h 1017 2011-04-27 18:42:58Z oconrad $
+ *********************************************************/
 
 ///////////////////////////////////////////////////////////
 //                                                       //
@@ -144,6 +147,15 @@ SAGA_API_DLL_EXPORT const SG_Char *	SG_Get_DataObject_Identifier	(TSG_Data_Objec
 SAGA_API_DLL_EXPORT const SG_Char *	SG_Get_DataObject_Name			(TSG_Data_Object_Type Type);
 
 
+///////////////////////////////////////////////////////////
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+SAGA_API_DLL_EXPORT void			SG_Set_History_Depth			(int Depth);
+SAGA_API_DLL_EXPORT int				SG_Get_History_Depth			(void);
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 ///////////////////////////////////////////////////////////
@@ -182,10 +194,14 @@ public:
 	void							Set_Name		(const SG_Char *Name);
 	const SG_Char *					Get_Name		(void)	const;
 
+	void							Set_Description	(const SG_Char *Description);
+	const SG_Char *					Get_Description	(void)	const;
+
 	virtual void					Set_Modified	(bool bOn = true)	{	m_bModified	= bOn;			}
 	bool							is_Modified		(void)	const		{	return( m_bModified );		}
 	bool							Update			(void);
 
+
 	CSG_MetaData &					Get_MetaData	(void)	const		{	return( *m_pMetaData );		}
 	CSG_MetaData &					Get_MetaData_DB	(void)				{	return( *m_pMetaData_DB );	}
 	CSG_MetaData &					Get_History		(void)				{	return( *m_pHistory );		}
@@ -198,18 +214,29 @@ public:
 	class CSG_PointCloud *			asPointCloud	(void)	{	return( Get_ObjectType() == DATAOBJECT_TYPE_PointCloud ? (class CSG_PointCloud *)this : NULL );	}
 	class CSG_Grid *				asGrid			(void)	{	return( Get_ObjectType() == DATAOBJECT_TYPE_Grid       ? (class CSG_Grid       *)this : NULL );	}
 
+	bool							Set_NoData_Value		(double Value);
+	bool							Set_NoData_Value_Range	(double loValue, double hiValue);
+	double							Get_NoData_Value		(void)	const	{	return( m_NoData_Value );	}
+	double							Get_NoData_hiValue		(void)	const	{	return( m_NoData_hiValue );	}
+
+	bool							is_NoData_Value			(double Value)	const
+	{
+		return( m_NoData_Value < m_NoData_hiValue ? m_NoData_Value <= Value && Value <= m_NoData_hiValue : Value == m_NoData_Value );
+	}
+
 
 protected:
 
-	void							Set_File_Name	(const SG_Char *File_Name);
-	void							Set_File_Type	(int File_Type);
+	void							Set_File_Name		(const SG_Char *File_Name);
+	void							Set_File_Type		(int File_Type);
 
-	bool							Load_MetaData	(const SG_Char *File_Name);
-	bool							Save_MetaData	(const SG_Char *File_Name);
+	bool							Load_MetaData		(const SG_Char *File_Name);
+	bool							Save_MetaData		(const SG_Char *File_Name);
 
-	void							Set_Update_Flag	(bool bOn = true)	{	m_bUpdate	= bOn;		}
-	bool							Get_Update_Flag	(void)				{	return( m_bUpdate );	}
-	virtual bool					On_Update		(void)				{	return( true );			}
+	void							Set_Update_Flag		(bool bOn = true)	{	m_bUpdate	= bOn;		}
+	bool							Get_Update_Flag		(void)				{	return( m_bUpdate );	}
+	virtual bool					On_Update			(void)				{	return( true );			}
+	virtual bool					On_NoData_Changed	(void)				{	return( true );			}
 
 
 private:
@@ -218,7 +245,10 @@ private:
 
 	int								m_File_Type;
 
-	CSG_String						m_File_Name, m_Name;
+	double							m_NoData_Value, m_NoData_hiValue;
+
+	CSG_String						m_File_Name, m_Name, m_Description;
+
 
 	CSG_MetaData					m_MetaData, *m_pMetaData, *m_pHistory, *m_pFile, *m_pProjection, *m_pMetaData_DB;
 
