@@ -1,3 +1,6 @@
+/**********************************************************
+ * Version $Id: grid_io.cpp 1083 2011-06-08 08:08:18Z reklov_w $
+ *********************************************************/
 
 ///////////////////////////////////////////////////////////
 //                                                       //
@@ -266,7 +269,7 @@ bool CSG_Grid::_Load_Binary(CSG_File &Stream, TSG_Data_Type File_Type, bool bFli
 		//-------------------------------------------------
 		else
 		{
-			nValueBytes	= SG_Data_Type_Get_Size(File_Type);
+			nValueBytes	= (int)SG_Data_Type_Get_Size(File_Type);
 			nxBytes		= Get_NX() * nValueBytes;
 
 			if( m_Type == File_Type && m_Memory_Type == GRID_MEMORY_Normal && !bSwapBytes )
@@ -379,7 +382,7 @@ bool CSG_Grid::_Save_Binary(CSG_File &Stream, int xA, int yA, int xN, int yN, TS
 		//-------------------------------------------------
 		else
 		{
-			nValueBytes	= SG_Data_Type_Get_Size(File_Type);
+			nValueBytes	= (int)SG_Data_Type_Get_Size(File_Type);
 			nxBytes		= xN * nValueBytes;
 
 			if( m_Type == File_Type && m_Memory_Type == GRID_MEMORY_Normal && !bSwapBytes )
@@ -530,9 +533,9 @@ bool CSG_Grid::_Save_ASCII(CSG_File &Stream, int xA, int yA, int xN, int yN, boo
 //---------------------------------------------------------
 #include "parameters.h"
 
-int SG_Grid_Cache_Check(CSG_Grid_System &m_System, int nValueBytes)
+long SG_Grid_Cache_Check(CSG_Grid_System &m_System, int nValueBytes)
 {
-	if(	SG_Grid_Cache_Get_Automatic() && m_System.Get_NCells() * nValueBytes > SG_Grid_Cache_Get_Threshold() )
+	if(	SG_Grid_Cache_Get_Automatic() && ((long) m_System.Get_NCells() * nValueBytes) > SG_Grid_Cache_Get_Threshold() )
 	{
 		switch( SG_Grid_Cache_Get_Confirm() )
 		{
@@ -547,7 +550,7 @@ int SG_Grid_Cache_Check(CSG_Grid_System &m_System, int nValueBytes)
 					LNG("Shall I activate file caching for new grid."),
 					m_System.Get_Name(),
 					LNG("Total memory size"),
-					(m_System.Get_NCells() * nValueBytes) / (double)N_MEGABYTE_BYTES
+					((long) m_System.Get_NCells() * nValueBytes) / (double)N_MEGABYTE_BYTES
 				);
 
 				if( SG_UI_Dlg_Continue(s, LNG("Activate Grid File Cache?")) )
@@ -575,7 +578,7 @@ int SG_Grid_Cache_Check(CSG_Grid_System &m_System, int nValueBytes)
 
 				//	Set_Buffer_Size((int)(p(SG_T("BUFFERSIZE"))->asDouble() * N_MEGABYTE_BYTES));
 
-					return( (int)(p(SG_T("BUFFERSIZE"))->asDouble() * N_MEGABYTE_BYTES) );
+					return( (long)(p(SG_T("BUFFERSIZE"))->asDouble() * N_MEGABYTE_BYTES) );
 				}
 			}
 			break;
@@ -589,7 +592,7 @@ int SG_Grid_Cache_Check(CSG_Grid_System &m_System, int nValueBytes)
 bool CSG_Grid::_Load_Native(const CSG_String &File_Name, TSG_Grid_Memory_Type Memory_Type)
 {
 	bool			bResult, hdr_bFlip, hdr_bSwapBytes;
-	int				iType, hdr_Offset, NX, NY;
+	long			hdr_Offset, iType, NX, NY;
 	double			Cellsize, xMin, yMin;
 	CSG_File		Stream;
 	TSG_Data_Type	hdr_Type;
@@ -629,7 +632,7 @@ bool CSG_Grid::_Load_Native(const CSG_String &File_Name, TSG_Grid_Memory_Type Me
 			case GRID_FILE_KEY_POSITION_YMIN:	yMin			= Value.asDouble();	break;
 			case GRID_FILE_KEY_CELLSIZE:		Cellsize		= Value.asDouble();	break;
 			case GRID_FILE_KEY_Z_FACTOR:		m_zFactor		= Value.asDouble();	break;
-			case GRID_FILE_KEY_NODATA_VALUE:	m_NoData_Value	= m_NoData_hiValue	= Value.asDouble();	break;
+			case GRID_FILE_KEY_NODATA_VALUE:	Set_NoData_Value(Value.asDouble());	break;
 
 			case GRID_FILE_KEY_DATAFILE_OFFSET:	hdr_Offset		= Value.asInt();	break;
 			case GRID_FILE_KEY_BYTEORDER_BIG:	hdr_bSwapBytes	= Value.Find(GRID_FILE_KEY_TRUE) >= 0;	break;
@@ -663,12 +666,12 @@ bool CSG_Grid::_Load_Native(const CSG_String &File_Name, TSG_Grid_Memory_Type Me
 		//-------------------------------------------------
 		// Load Data...
 
-		if( hdr_Type < SG_DATATYPE_Undefined && m_System.Assign(Cellsize, xMin, yMin, NX, NY) )
+		if( m_System.Assign(Cellsize, xMin, yMin, (int) NX, (int) NY) )
 		{
 			//---------------------------------------------
 			// ASCII...
 
-			if( hdr_Type >= SG_DATATYPE_Undefined )
+			if( !SG_Data_Type_is_Numeric(hdr_Type) )
 			{
 				if( m_Type >= SG_DATATYPE_Undefined )
 				{
@@ -680,7 +683,7 @@ bool CSG_Grid::_Load_Native(const CSG_String &File_Name, TSG_Grid_Memory_Type Me
 				||	Stream.Open(SG_File_Make_Path(NULL, File_Name, SG_T("sdat"))	, SG_FILE_R, false) )
 				{
 					Stream.Seek(hdr_Offset);
-					bResult	= _Load_ASCII(Stream, Memory_Type);
+					bResult	= _Load_ASCII(Stream, Memory_Type, hdr_bFlip);
 				}
 			}
 
@@ -722,6 +725,11 @@ bool CSG_Grid::_Load_Native(const CSG_String &File_Name, TSG_Grid_Memory_Type Me
 		}
 	}
 
+	if( bResult )
+	{
+		Get_Projection().Load(SG_File_Make_Path(NULL, File_Name, SG_T("prj")), SG_PROJ_FMT_WKT);
+	}
+
 	return( bResult );
 }
 
@@ -748,7 +756,7 @@ bool CSG_Grid::_Save_Native(const CSG_String &File_Name, int xA, int yA, int xN,
 		Stream.Printf(SG_T("%s\t= %d\n")	, gSG_Grid_File_Key_Names[ GRID_FILE_KEY_CELLCOUNT_Y	], yN );
 		Stream.Printf(SG_T("%s\t= %.10f\n")	, gSG_Grid_File_Key_Names[ GRID_FILE_KEY_CELLSIZE		], Get_Cellsize() );
 		Stream.Printf(SG_T("%s\t= %f\n")	, gSG_Grid_File_Key_Names[ GRID_FILE_KEY_Z_FACTOR		], m_zFactor );
-		Stream.Printf(SG_T("%s\t= %f\n")	, gSG_Grid_File_Key_Names[ GRID_FILE_KEY_NODATA_VALUE	], m_NoData_Value );
+		Stream.Printf(SG_T("%s\t= %f\n")	, gSG_Grid_File_Key_Names[ GRID_FILE_KEY_NODATA_VALUE	], Get_NoData_Value() );
 		Stream.Printf(SG_T("%s\t= %s\n")	, gSG_Grid_File_Key_Names[ GRID_FILE_KEY_TOPTOBOTTOM	], GRID_FILE_KEY_FALSE );
 
 
@@ -766,6 +774,8 @@ bool CSG_Grid::_Save_Native(const CSG_String &File_Name, int xA, int yA, int xN,
 				bResult		= _Save_ASCII	(Stream, xA, yA, xN, yN);
 			}
 		}
+
+		Get_Projection().Save(SG_File_Make_Path(NULL, File_Name, SG_T("prj")), SG_PROJ_FMT_WKT);
 	}
 
 	return( bResult );
@@ -786,7 +796,7 @@ int CSG_Grid::_Load_Native_Get_Key(CSG_File &Stream, CSG_String &Value)
 
 	if( Stream.Read_Line(sLine) && (i = sLine.Find('=')) > 0 )
 	{
-		Value.Printf(sLine.AfterFirst('='));
+		Value	= sLine.AfterFirst('=');
 		Value.Trim();
 
 		sLine.Remove(i);
