@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: mat_spline.cpp 911 2011-02-14 16:38:15Z reklov_w $
+ * Version $Id: mat_spline.cpp 1173 2011-09-23 14:39:27Z oconrad $
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -139,7 +139,7 @@ void CSG_Spline::Add(double x, double y)
 	if( m_nValues >= m_nBuffer )
 	{
 		m_nBuffer	+= 64;
-		m_Values	 = (TSG_Point_Z *)SG_Realloc(m_Values, m_nValues * sizeof(TSG_Point_Z));
+		m_Values	 = (TSG_Point_Z *)SG_Realloc(m_Values, m_nBuffer * sizeof(TSG_Point_Z));
 	}
 
 	m_nValues++;
