@@ -1,3 +1,6 @@
+/**********************************************************
+ * Version $Id: parameters.h 1200 2011-10-25 15:23:04Z oconrad $
+ *********************************************************/
 
 ///////////////////////////////////////////////////////////
 //                                                       //
@@ -89,6 +92,7 @@
 #define PARAMETER_OUTPUT					0x02
 #define PARAMETER_OPTIONAL					0x04
 #define PARAMETER_INFORMATION				0x08
+#define PARAMETER_IGNORE_PROJECTION			0x10
 
 #define PARAMETER_INPUT_OPTIONAL			(PARAMETER_INPUT  | PARAMETER_OPTIONAL)
 #define PARAMETER_OUTPUT_OPTIONAL			(PARAMETER_OUTPUT | PARAMETER_OPTIONAL)
@@ -163,8 +167,9 @@ TSG_Parameter_Type;
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-SAGA_API_DLL_EXPORT const SG_Char *		SG_Parameter_Type_Get_Identifier	(TSG_Parameter_Type Type);
 SAGA_API_DLL_EXPORT const SG_Char *		SG_Parameter_Type_Get_Name			(TSG_Parameter_Type Type);
+SAGA_API_DLL_EXPORT const SG_Char *		SG_Parameter_Type_Get_Identifier	(TSG_Parameter_Type Type);
+SAGA_API_DLL_EXPORT TSG_Parameter_Type	SG_Parameter_Type_Get_Type			(const CSG_String &Identifier);
 
 
 ///////////////////////////////////////////////////////////
@@ -185,7 +190,12 @@ class CSG_Parameter;
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-typedef int		(* TSG_PFNC_Parameter_Changed)	(CSG_Parameter *pSender);
+#define PARAMETER_CHECK_VALUES				0x01
+#define PARAMETER_CHECK_ENABLE				0x02
+#define PARAMETER_CHECK_ALL					(PARAMETER_CHECK_VALUES | PARAMETER_CHECK_ENABLE)
+
+//---------------------------------------------------------
+typedef int		(* TSG_PFNC_Parameter_Changed)	(CSG_Parameter *pParameter, int Flags);
 
 
 ///////////////////////////////////////////////////////////
@@ -212,9 +222,9 @@ public:
 	bool						Assign					(CSG_Parameter_Data *pSource);
 	bool						Serialize				(CSG_MetaData &Entry, bool bSave);
 
-	virtual bool				Set_Value				(int Value);
+	virtual bool				Set_Value				(int    Value);
 	virtual bool				Set_Value				(double Value);
-	virtual bool				Set_Value				(void *Value);
+	virtual bool				Set_Value				(void  *Value);
 
 	virtual int					asInt					(void);
 	virtual double				asDouble				(void);
@@ -222,12 +232,19 @@ public:
 
 	virtual const SG_Char *		asString				(void);
 
+	CSG_String					Get_Default				(void)	{	return( m_Default );	}
+	void						Set_Default				(int            Value);
+	void						Set_Default				(double         Value);
+	void						Set_Default				(const SG_Char *Value);
+
+	virtual bool				Restore_Default			(void)	{	return( false );		}
+
 
 protected:
 
 	int							m_Constraint;
 
-	CSG_String					m_String;
+	CSG_String					m_String, m_Default;
 
 	CSG_Parameter				*m_pOwner;
 
@@ -237,6 +254,11 @@ protected:
 
 };
 
+
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
 //---------------------------------------------------------
 class SAGA_API_DLL_EXPORT CSG_Parameter_Node : public CSG_Parameter_Data
 {
@@ -248,6 +270,11 @@ public:
 
 };
 
+
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
 //---------------------------------------------------------
 class SAGA_API_DLL_EXPORT CSG_Parameter_Bool : public CSG_Parameter_Data
 {
@@ -257,13 +284,15 @@ public:
 
 	virtual TSG_Parameter_Type	Get_Type				(void)	{	return( PARAMETER_TYPE_Bool );	}
 
-	virtual bool				Set_Value				(int Value);
+	virtual bool				Set_Value				(int    Value);
 	virtual bool				Set_Value				(double Value);
 
-	virtual int					asInt					(void)	{	return( m_Value );	}
+	virtual int					asInt					(void)	{	return( m_Value );		}
 
 	virtual const SG_Char *		asString				(void);
 
+	virtual bool				Restore_Default			(void)	{	return( Set_Value(m_Default.asInt()) );	}
+
 
 protected:
 
@@ -275,6 +304,11 @@ protected:
 
 };
 
+
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
 //---------------------------------------------------------
 class SAGA_API_DLL_EXPORT CSG_Parameter_Value : public CSG_Parameter_Data
 {
@@ -304,6 +338,11 @@ protected:
 
 };
 
+
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
 //---------------------------------------------------------
 class SAGA_API_DLL_EXPORT CSG_Parameter_Int : public CSG_Parameter_Value
 {
@@ -313,14 +352,16 @@ public:
 
 	virtual TSG_Parameter_Type	Get_Type				(void)	{	return( PARAMETER_TYPE_Int );		}
 
-	virtual bool				Set_Value				(void *Value);
-	virtual bool				Set_Value				(int Value);
+	virtual bool				Set_Value				(void  *Value);
+	virtual bool				Set_Value				(int    Value);
 	virtual bool				Set_Value				(double Value);
 
 	virtual int					asInt					(void)	{	return( m_Value );		}
 	virtual double				asDouble				(void)	{	return( m_Value );		}
 	virtual const SG_Char *		asString				(void);
 
+	virtual bool				Restore_Default			(void)	{	return( Set_Value(m_Default.asInt()) );	}
+
 
 protected:
 
@@ -331,6 +372,11 @@ protected:
 
 };
 
+
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
 //---------------------------------------------------------
 class SAGA_API_DLL_EXPORT CSG_Parameter_Double : public CSG_Parameter_Value
 {
@@ -340,14 +386,16 @@ public:
 
 	virtual TSG_Parameter_Type	Get_Type				(void)	{	return( PARAMETER_TYPE_Double );	}
 
-	virtual bool				Set_Value				(int Value);
+	virtual bool				Set_Value				(int    Value);
 	virtual bool				Set_Value				(double Value);
-	virtual bool				Set_Value				(void *Value);
+	virtual bool				Set_Value				(void  *Value);
 
 	virtual int					asInt					(void)	{	return( (int)m_Value );	}
 	virtual double				asDouble				(void)	{	return( m_Value );		}
 	virtual const SG_Char *		asString				(void);
 
+	virtual bool				Restore_Default			(void)	{	return( Set_Value(m_Default.asDouble()) );	}
+
 
 protected:
 
@@ -358,6 +406,11 @@ protected:
 
 };
 
+
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
 //---------------------------------------------------------
 class SAGA_API_DLL_EXPORT CSG_Parameter_Degree : public CSG_Parameter_Double
 {
@@ -373,6 +426,11 @@ public:
 
 };
 
+
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
 //---------------------------------------------------------
 class SAGA_API_DLL_EXPORT CSG_Parameter_Range : public CSG_Parameter_Data
 {
@@ -395,6 +453,8 @@ public:
 	CSG_Parameter *				Get_LoParm				(void)	{	return( pLo );	}
 	CSG_Parameter *				Get_HiParm				(void)	{	return( pHi );	}
 
+	virtual bool				Restore_Default			(void);
+
 
 protected:
 
@@ -408,6 +468,11 @@ protected:
 
 };
 
+
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
 //---------------------------------------------------------
 class SAGA_API_DLL_EXPORT CSG_Parameter_Choice : public CSG_Parameter_Int
 {
@@ -425,6 +490,10 @@ public:
 
 	const SG_Char *				Get_Item				(int Index);
 
+	bool						Get_Data				(int        &Value);
+	bool						Get_Data				(double     &Value);
+	bool						Get_Data				(CSG_String &Value);
+
 	int							Get_Count				(void)	{	return( Items.Get_Count() );	}
 
 
@@ -437,6 +506,11 @@ protected:
 
 };
 
+
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
 //---------------------------------------------------------
 class SAGA_API_DLL_EXPORT CSG_Parameter_String : public CSG_Parameter_Data
 {
@@ -446,7 +520,7 @@ public:
 
 	virtual TSG_Parameter_Type	Get_Type				(void)	{	return( PARAMETER_TYPE_String );	}
 
-	virtual const SG_Char *		asString				(void);
+	virtual const SG_Char *		asString				(void)	{	return( m_String );	}
 
 	virtual bool				is_Valid				(void);
 
@@ -455,6 +529,8 @@ public:
 	void						Set_Password			(bool bOn);
 	bool						is_Password				(void);
 
+	virtual bool				Restore_Default			(void)	{	return( Set_Value((void *)m_Default.c_str()) );	}
+
 
 protected:
 
@@ -466,6 +542,11 @@ protected:
 
 };
 
+
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
 //---------------------------------------------------------
 class SAGA_API_DLL_EXPORT CSG_Parameter_Text : public CSG_Parameter_String
 {
@@ -477,6 +558,11 @@ public:
 
 };
 
+
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
 //---------------------------------------------------------
 class SAGA_API_DLL_EXPORT CSG_Parameter_File_Name : public CSG_Parameter_String
 {
@@ -512,29 +598,35 @@ protected:
 
 };
 
+
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
 //---------------------------------------------------------
 class SAGA_API_DLL_EXPORT CSG_Parameter_Font : public CSG_Parameter_Data
 {
 public:
 	CSG_Parameter_Font(CSG_Parameter *pOwner, long Constraint);
-	virtual ~CSG_Parameter_Font(void);
+	virtual ~CSG_Parameter_Font(void)	{}
 
 	virtual TSG_Parameter_Type	Get_Type				(void)	{	return( PARAMETER_TYPE_Font );		}
 
-	virtual bool				Set_Value				(int Value);
+	virtual int					asInt					(void)	{	return( m_Color );					}
+	virtual void *				asPointer				(void)	{	return( (void *)m_Font.c_str() );	}
+	virtual const SG_Char *		asString				(void)	{	return( m_String );					}
+
+	virtual bool				Set_Value				(int   Value);
 	virtual bool				Set_Value				(void *Value);
 
-	virtual int					asInt					(void)	{	return( m_Color );	}
-	virtual void *				asPointer				(void)	{	return( m_pFont );	}
-
-	virtual const SG_Char *		asString				(void);
+	virtual bool				Restore_Default			(void);
 
 
 protected:
 
 	int							m_Color;
 
-	class wxFont				*m_pFont;
+	CSG_String					m_Font;
 
 
 	virtual void				On_Assign				(CSG_Parameter_Data *pSource);
@@ -542,6 +634,11 @@ protected:
 
 };
 
+
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
 //---------------------------------------------------------
 class SAGA_API_DLL_EXPORT CSG_Parameter_Color : public CSG_Parameter_Int
 {
@@ -558,6 +655,11 @@ protected:
 
 };
 
+
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
 //---------------------------------------------------------
 class SAGA_API_DLL_EXPORT CSG_Parameter_Colors : public CSG_Parameter_Data
 {
@@ -582,6 +684,11 @@ protected:
 
 };
 
+
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
 //---------------------------------------------------------
 class SAGA_API_DLL_EXPORT CSG_Parameter_Fixed_Table : public CSG_Parameter_Data
 {
@@ -605,6 +712,11 @@ protected:
 
 };
 
+
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
 //---------------------------------------------------------
 class SAGA_API_DLL_EXPORT CSG_Parameter_Grid_System : public CSG_Parameter_Data
 {
@@ -631,6 +743,11 @@ protected:
 
 };
 
+
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
 //---------------------------------------------------------
 class SAGA_API_DLL_EXPORT CSG_Parameter_Table_Field : public CSG_Parameter_Int
 {
@@ -642,7 +759,8 @@ public:
 
 	virtual const SG_Char *		asString				(void);
 
-	virtual bool				Set_Value				(int Value);
+	virtual bool				Set_Value				(int   Value);
+	virtual bool				Set_Value				(void *Value);
 
 	CSG_Table *					Get_Table				(void);
 
@@ -651,8 +769,16 @@ protected:
 
 	bool						m_bAllowNone;
 
+
+	virtual void				On_Assign				(CSG_Parameter_Data *pSource);
+
 };
 
+
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
 //---------------------------------------------------------
 class SAGA_API_DLL_EXPORT CSG_Parameter_Data_Object : public CSG_Parameter_Data
 {
@@ -680,6 +806,11 @@ protected:
 
 };
 
+
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
 //---------------------------------------------------------
 class SAGA_API_DLL_EXPORT CSG_Parameter_Data_Object_Output : public CSG_Parameter_Data_Object
 {
@@ -701,6 +832,11 @@ protected:
 
 };
 
+
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
 //---------------------------------------------------------
 class SAGA_API_DLL_EXPORT CSG_Parameter_Grid : public CSG_Parameter_Data_Object
 {
@@ -727,6 +863,11 @@ protected:
 
 };
 
+
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
 //---------------------------------------------------------
 class SAGA_API_DLL_EXPORT CSG_Parameter_Table : public CSG_Parameter_Data_Object
 {
@@ -740,6 +881,11 @@ public:
 
 };
 
+
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
 //---------------------------------------------------------
 class SAGA_API_DLL_EXPORT CSG_Parameter_Shapes : public CSG_Parameter_Data_Object
 {
@@ -764,6 +910,11 @@ protected:
 
 };
 
+
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
 //---------------------------------------------------------
 class SAGA_API_DLL_EXPORT CSG_Parameter_TIN : public CSG_Parameter_Data_Object
 {
@@ -777,6 +928,11 @@ public:
 
 };
 
+
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
 //---------------------------------------------------------
 class SAGA_API_DLL_EXPORT CSG_Parameter_PointCloud : public CSG_Parameter_Data_Object
 {
@@ -795,6 +951,11 @@ protected:
 
 };
 
+
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
 //---------------------------------------------------------
 class SAGA_API_DLL_EXPORT CSG_Parameter_List : public CSG_Parameter_Data
 {
@@ -829,6 +990,11 @@ private:
 
 };
 
+
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
 //---------------------------------------------------------
 class SAGA_API_DLL_EXPORT CSG_Parameter_Grid_List : public CSG_Parameter_List
 {
@@ -844,6 +1010,11 @@ public:
 
 };
 
+
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
 //---------------------------------------------------------
 class SAGA_API_DLL_EXPORT CSG_Parameter_Table_List : public CSG_Parameter_List
 {
@@ -857,6 +1028,11 @@ public:
 
 };
 
+
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
 //---------------------------------------------------------
 class SAGA_API_DLL_EXPORT CSG_Parameter_Shapes_List : public CSG_Parameter_List
 {
@@ -881,6 +1057,11 @@ protected:
 
 };
 
+
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
 //---------------------------------------------------------
 class SAGA_API_DLL_EXPORT CSG_Parameter_TIN_List : public CSG_Parameter_List
 {
@@ -894,6 +1075,11 @@ public:
 
 };
 
+
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
 //---------------------------------------------------------
 class SAGA_API_DLL_EXPORT CSG_Parameter_PointCloud_List : public CSG_Parameter_List
 {
@@ -907,6 +1093,11 @@ public:
 
 };
 
+
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
 //---------------------------------------------------------
 class SAGA_API_DLL_EXPORT CSG_Parameter_Parameters : public CSG_Parameter_Data
 {
@@ -919,6 +1110,8 @@ public:
 	virtual const SG_Char *		asString				(void);
 	virtual void *				asPointer				(void)		{	return( m_pParameters );	}
 
+	virtual bool				Restore_Default			(void);
+
 
 protected:
 
@@ -933,6 +1126,46 @@ private:
 };
 
 
+///////////////////////////////////////////////////////////
+//														 //
+//				Grid Target Selector					 //
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+class SAGA_API_DLL_EXPORT CSG_Parameters_Grid_Target
+{
+public:
+	CSG_Parameters_Grid_Target(void);
+
+	void						Create					(void);
+
+	bool						Add_Parameters_User		(CSG_Parameters *pParameters, bool bAddDefaultGrid = true);
+	bool						Add_Parameters_Grid		(CSG_Parameters *pParameters, bool bAddDefaultGrid = true);
+	bool						Add_Parameters_System	(CSG_Parameters *pParameters);
+
+	bool						Add_Grid_Parameter		(const CSG_String &Identifier, const CSG_String &Name, bool bOptional);
+
+	bool						On_User_Changed			(CSG_Parameters *pParameters, CSG_Parameter *pParameter);
+
+	bool						Init_User				(const TSG_Rect &Extent, int Rows = 100);
+
+	CSG_Grid *					Get_User				(                              TSG_Data_Type Type = SG_DATATYPE_Float);
+	CSG_Grid *					Get_User				(const CSG_String &Identifier, TSG_Data_Type Type = SG_DATATYPE_Float);
+	CSG_Grid *					Get_Grid				(                              TSG_Data_Type Type = SG_DATATYPE_Float);
+	CSG_Grid *					Get_Grid				(const CSG_String &Identifier, TSG_Data_Type Type = SG_DATATYPE_Float);
+
+	bool						Get_System_User			(CSG_Grid_System &System);
+	bool						Get_System				(CSG_Grid_System &System);
+
+
+private:
+
+	CSG_Parameters				*m_pUser, *m_pGrid, *m_pSystem;
+
+};
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 //					CSG_Parameter						 //
@@ -963,11 +1196,13 @@ public:
 	bool						Set_Enabled				(bool bEnabled);
 	bool						is_Enabled				(void)	{	return( m_bEnabled );				}
 
+	bool						ignore_Projection		(void)	{	return( !!(m_pData->Get_Constraint() & PARAMETER_IGNORE_PROJECTION) );	}
+
 	bool						is_Valid				(void)	{	return( m_pData->is_Valid() );		}
-	bool						is_Input				(void)	{	return( !!(m_pData->Get_Constraint() & PARAMETER_INPUT)	      );	}
-	bool						is_Output				(void)	{	return( !!(m_pData->Get_Constraint() & PARAMETER_OUTPUT)      );	}
-	bool						is_Optional				(void)	{	return( !!(m_pData->Get_Constraint() & PARAMETER_OPTIONAL)    );	}
-	bool						is_Information			(void)	{	return( !!(m_pData->Get_Constraint() & PARAMETER_INFORMATION) );	}
+	bool						is_Input				(void)	{	return( !!(m_pData->Get_Constraint() & PARAMETER_INPUT)	        );	}
+	bool						is_Output				(void)	{	return( !!(m_pData->Get_Constraint() & PARAMETER_OUTPUT)        );	}
+	bool						is_Optional				(void)	{	return( !!(m_pData->Get_Constraint() & PARAMETER_OPTIONAL)      );	}
+	bool						is_Information			(void)	{	return( !!(m_pData->Get_Constraint() & PARAMETER_INFORMATION)   );	}
 	bool						is_Option				(void);
 	bool						is_DataObject			(void);
 	bool						is_DataObject_List		(void);
@@ -982,42 +1217,49 @@ public:
 	bool						Set_Value				(double         Value);
 	bool						Set_Value				(void          *Value);
 	bool						Set_Value				(const SG_Char *Value);
+	bool						Set_Value				(CSG_Parameter *Value);
 
-	bool						has_Changed				(void);
+	void						Set_Default				(int            Value)	{	m_pData->Set_Default(Value);	}
+	void						Set_Default				(double         Value)	{	m_pData->Set_Default(Value);	}
+	void						Set_Default				(const SG_Char *Value)	{	m_pData->Set_Default(Value);	}
 
-	bool						asBool					(void)	{	return( (bool          )!!m_pData->asInt	() );	}
-	int							asInt					(void)	{	return( (int           )m_pData->asInt		() );	}
-	long						asColor					(void)	{	return( (long          )m_pData->asInt		() );	}
-	double						asDouble				(void)	{	return( (double        )m_pData->asDouble	() );	}
+	bool						Restore_Default			(void)	{	return( m_pData->Restore_Default() );	}
 
-	void *						asPointer				(void)	{	return( (void            *)m_pData->asPointer	() );	}
+	bool						has_Changed				(int Check_Flags = PARAMETER_CHECK_ALL);
 
-	const SG_Char *				asString				(void)	{	return( (const SG_Char   *)m_pData->asString	() );	}
-	class wxFont *				asFont					(void)	{	return( (wxFont          *)m_pData->asPointer	() );	}
-	CSG_Colors *				asColors				(void)	{	return( (CSG_Colors      *)m_pData->asPointer	() );	}
-	CSG_Grid_System *			asGrid_System			(void)	{	return( (CSG_Grid_System *)m_pData->asPointer	() );	}
+	bool						asBool					(void)	{	return( (bool             )!!m_pData->asInt  () );	}
+	int							asInt					(void)	{	return( (int              )m_pData->asInt    () );	}
+	long						asColor					(void)	{	return( (long             )m_pData->asInt    () );	}
+	double						asDouble				(void)	{	return( (double           )m_pData->asDouble () );	}
 
-	CSG_Data_Object *			asDataObject			(void)	{	return( (CSG_Data_Object *)m_pData->asPointer	() );	}
-	CSG_Grid *					asGrid					(void)	{	return( (CSG_Grid        *)m_pData->asPointer	() );	}
-	CSG_Table *					asTable					(void)	{	return( (CSG_Table       *)m_pData->asPointer	() );	}
-	CSG_Shapes *				asShapes				(void)	{	return( (CSG_Shapes      *)m_pData->asPointer	() );	}
-	CSG_TIN *					asTIN					(void)	{	return( (CSG_TIN         *)m_pData->asPointer	() );	}
-	CSG_PointCloud *			asPointCloud			(void)	{	return( (CSG_PointCloud  *)m_pData->asPointer	() );	}
+	void *						asPointer				(void)	{	return( (void            *)m_pData->asPointer() );	}
 
-	CSG_Parameter_Value *		asValue					(void)	{	return( (CSG_Parameter_Value       *)m_pData );		}
-	CSG_Parameter_Choice *		asChoice				(void)	{	return( (CSG_Parameter_Choice      *)m_pData );		}
-	CSG_Parameter_Range *		asRange					(void)	{	return( (CSG_Parameter_Range       *)m_pData );		}
-	CSG_Parameter_File_Name *	asFilePath				(void)	{	return( (CSG_Parameter_File_Name   *)m_pData );		}
+	const SG_Char *				asString				(void)	{	return( (const SG_Char   *)m_pData->asString () );	}
+	CSG_Colors *				asColors				(void)	{	return( (CSG_Colors      *)m_pData->asPointer() );	}
+	CSG_Grid_System *			asGrid_System			(void)	{	return( (CSG_Grid_System *)m_pData->asPointer() );	}
+	const SG_Char *				asFont					(void)	{	return( (const SG_Char   *)m_pData->asPointer() );	}
 
-	CSG_Parameter_List *		asList					(void)	{	return( (CSG_Parameter_List        *)m_pData );		}
-	CSG_Parameter_Grid_List *	asGridList				(void)	{	return( (CSG_Parameter_Grid_List   *)m_pData );		}
-	CSG_Parameter_Table_List *	asTableList				(void)	{	return( (CSG_Parameter_Table_List  *)m_pData );		}
-	CSG_Parameter_Shapes_List *	asShapesList			(void)	{	return( (CSG_Parameter_Shapes_List *)m_pData );		}
-	CSG_Parameter_TIN_List *	asTINList				(void)	{	return( (CSG_Parameter_TIN_List    *)m_pData );		}
+	CSG_Data_Object *			asDataObject			(void)	{	return( (CSG_Data_Object *)m_pData->asPointer() );	}
+	CSG_Grid *					asGrid					(void)	{	return( (CSG_Grid        *)m_pData->asPointer() );	}
+	CSG_Table *					asTable					(void)	{	return( (CSG_Table       *)m_pData->asPointer() );	}
+	CSG_Shapes *				asShapes				(void)	{	return( (CSG_Shapes      *)m_pData->asPointer() );	}
+	CSG_TIN *					asTIN					(void)	{	return( (CSG_TIN         *)m_pData->asPointer() );	}
+	CSG_PointCloud *			asPointCloud			(void)	{	return( (CSG_PointCloud  *)m_pData->asPointer() );	}
+
+	CSG_Parameters *			asParameters			(void)	{	return( (CSG_Parameters  *)m_pData->asPointer() );	}
+
+	CSG_Parameter_Value *		asValue					(void)	{	return( (CSG_Parameter_Value           *)m_pData );	}
+	CSG_Parameter_Choice *		asChoice				(void)	{	return( (CSG_Parameter_Choice          *)m_pData );	}
+	CSG_Parameter_Range *		asRange					(void)	{	return( (CSG_Parameter_Range           *)m_pData );	}
+	CSG_Parameter_File_Name *	asFilePath				(void)	{	return( (CSG_Parameter_File_Name       *)m_pData );	}
+
+	CSG_Parameter_List *		asList					(void)	{	return( (CSG_Parameter_List            *)m_pData );	}
+	CSG_Parameter_Grid_List *	asGridList				(void)	{	return( (CSG_Parameter_Grid_List       *)m_pData );	}
+	CSG_Parameter_Table_List *	asTableList				(void)	{	return( (CSG_Parameter_Table_List      *)m_pData );	}
+	CSG_Parameter_Shapes_List *	asShapesList			(void)	{	return( (CSG_Parameter_Shapes_List     *)m_pData );	}
+	CSG_Parameter_TIN_List *	asTINList				(void)	{	return( (CSG_Parameter_TIN_List        *)m_pData );	}
 	CSG_Parameter_PointCloud_List *	asPointCloudList	(void)	{	return( (CSG_Parameter_PointCloud_List *)m_pData );	}
 
-	CSG_Parameters *			asParameters			(void)	{	return( (CSG_Parameters *)m_pData->asPointer	() );	}
-
 	//-----------------------------------------------------
 	bool						Assign					(CSG_Parameter *pSource);
 
@@ -1072,17 +1314,17 @@ public:
 	void						Destroy					(void);
 
 	//-----------------------------------------------------
-	void *						Get_Owner				(void)	{	return( m_pOwner );			}
-	int							Get_Count				(void)	{	return( m_nParameters );	}
+	void *						Get_Owner				(void)	const	{	return( m_pOwner );			}
+	int							Get_Count				(void)	const	{	return( m_nParameters );	}
 
 	void						Set_Identifier			(const SG_Char *String);
-	const SG_Char *				Get_Identifier			(void);
+	const SG_Char *				Get_Identifier			(void)	const	{	return( m_Identifier );		}
 
 	void						Set_Name				(const SG_Char *String);
-	const SG_Char *				Get_Name				(void);
+	const SG_Char *				Get_Name				(void)	const	{	return( m_Name );			}
 
 	void						Set_Description			(const SG_Char *String);
-	const SG_Char *				Get_Description			(void);
+	const SG_Char *				Get_Description			(void)	const	{	return( m_Description );	}
 
 	void						Set_Translation			(CSG_Translator &Translator);
 
@@ -1094,11 +1336,17 @@ public:
 
 	//-----------------------------------------------------
 	CSG_Parameter *				Get_Parameter			(int iParameter);
-	CSG_Parameter *				operator()				(int iParameter)			{	return( Get_Parameter(iParameter) );	}
-
 	CSG_Parameter *				Get_Parameter			(const SG_Char *Identifier);
+
+	CSG_Parameter *				operator()				(int iParameter)			{	return( Get_Parameter(iParameter) );	}
 	CSG_Parameter *				operator()				(const SG_Char *Identifier)	{	return( Get_Parameter(Identifier) );	}
 
+	//-----------------------------------------------------
+	bool						Del_Parameter			(int iParameter);
+	bool						Del_Parameter			(const SG_Char *Identifier);
+
+	bool						Del_Parameters			(void);
+
 	//-----------------------------------------------------
 	CSG_Parameter *				Add_Node				(CSG_Parameter *pParent, const SG_Char *Identifier, const SG_Char *Name, const SG_Char *Description);
 
@@ -1115,9 +1363,9 @@ public:
 
 	CSG_Parameter *				Add_FilePath			(CSG_Parameter *pParent, const SG_Char *Identifier, const SG_Char *Name, const SG_Char *Description, const SG_Char *Filter = NULL, const SG_Char *Default = NULL, bool bSave = false, bool bDirectory = false, bool bMultiple = false);
 
-	CSG_Parameter *				Add_Font				(CSG_Parameter *pParent, const SG_Char *Identifier, const SG_Char *Name, const SG_Char *Description, class wxFont *pInit = NULL);
-	CSG_Parameter *				Add_Colors				(CSG_Parameter *pParent, const SG_Char *Identifier, const SG_Char *Name, const SG_Char *Description, CSG_Colors      *pInit = NULL);
-	CSG_Parameter *				Add_FixedTable			(CSG_Parameter *pParent, const SG_Char *Identifier, const SG_Char *Name, const SG_Char *Description, CSG_Table   *pTemplate = NULL);
+	CSG_Parameter *				Add_Font				(CSG_Parameter *pParent, const SG_Char *Identifier, const SG_Char *Name, const SG_Char *Description, const SG_Char *pInit = NULL);
+	CSG_Parameter *				Add_Colors				(CSG_Parameter *pParent, const SG_Char *Identifier, const SG_Char *Name, const SG_Char *Description, CSG_Colors    *pInit = NULL);
+	CSG_Parameter *				Add_FixedTable			(CSG_Parameter *pParent, const SG_Char *Identifier, const SG_Char *Name, const SG_Char *Description, CSG_Table     *pInit = NULL);
 
 	CSG_Parameter *				Add_Grid_System			(CSG_Parameter *pParent, const SG_Char *Identifier, const SG_Char *Name, const SG_Char *Description, CSG_Grid_System *pInit = NULL);
 	CSG_Parameter *				Add_Grid				(CSG_Parameter *pParent, const SG_Char *Identifier, const SG_Char *Name, const SG_Char *Description, int Constraint, bool bSystem_Dependent = true, TSG_Data_Type Preferred_Type = SG_DATATYPE_Undefined);
@@ -1145,10 +1393,12 @@ public:
 
 	//-----------------------------------------------------
 	bool						Set_Parameter			(const SG_Char *Identifier, CSG_Parameter *pSource);
-	bool						Set_Parameter			(const SG_Char *Identifier, int Type, int           Value);
-	bool						Set_Parameter			(const SG_Char *Identifier, int Type, double        Value);
-	bool						Set_Parameter			(const SG_Char *Identifier, int Type, void          *Value);
-	bool						Set_Parameter			(const SG_Char *Identifier, int Type, const SG_Char *Value);
+	bool						Set_Parameter			(const SG_Char *Identifier, int            Value, int Type = PARAMETER_TYPE_Undefined);
+	bool						Set_Parameter			(const SG_Char *Identifier, double         Value, int Type = PARAMETER_TYPE_Undefined);
+	bool						Set_Parameter			(const SG_Char *Identifier, void          *Value, int Type = PARAMETER_TYPE_Undefined);
+	bool						Set_Parameter			(const SG_Char *Identifier, const SG_Char *Value, int Type = PARAMETER_TYPE_Undefined);
+
+	bool						Restore_Defaults		(void);
 
 	int							Assign					(CSG_Parameters *pSource);
 	int							Assign_Values			(CSG_Parameters *pSource);
@@ -1174,6 +1424,7 @@ public:
 #ifdef _SAGA_UNICODE
 	CSG_Parameter *				Get_Parameter			(const char *Identifier);
 	CSG_Parameter *				operator()				(const char *Identifier)	{	return( Get_Parameter(Identifier) );	}
+	bool						Del_Parameter			(const char *Identifier);
 	CSG_Parameter *				Add_Node				(CSG_Parameter *pParent, const char *Identifier, const SG_Char *Name, const SG_Char *Description);
 	CSG_Parameter *				Add_Value				(CSG_Parameter *pParent, const char *Identifier, const SG_Char *Name, const SG_Char *Description, TSG_Parameter_Type Type, double Value = 0.0, double Minimum = 0.0, bool bMinimum = false, double Maximum = 0.0, bool bMaximum = false);
 	CSG_Parameter *				Add_Info_Value			(CSG_Parameter *pParent, const char *Identifier, const SG_Char *Name, const SG_Char *Description, TSG_Parameter_Type Type, double Value = 0.0);
@@ -1183,9 +1434,9 @@ public:
 	CSG_Parameter *				Add_String				(CSG_Parameter *pParent, const char *Identifier, const SG_Char *Name, const SG_Char *Description, const SG_Char *String, bool bLongText = false, bool bPassword = false);
 	CSG_Parameter *				Add_Info_String			(CSG_Parameter *pParent, const char *Identifier, const SG_Char *Name, const SG_Char *Description, const SG_Char *String, bool bLongText = false);
 	CSG_Parameter *				Add_FilePath			(CSG_Parameter *pParent, const char *Identifier, const SG_Char *Name, const SG_Char *Description, const SG_Char *Filter = NULL, const SG_Char *Default = NULL, bool bSave = false, bool bDirectory = false, bool bMultiple = false);
-	CSG_Parameter *				Add_Font				(CSG_Parameter *pParent, const char *Identifier, const SG_Char *Name, const SG_Char *Description, class wxFont *pInit = NULL);
+	CSG_Parameter *				Add_Font				(CSG_Parameter *pParent, const char *Identifier, const SG_Char *Name, const SG_Char *Description, const SG_Char   *pInit = NULL);
 	CSG_Parameter *				Add_Colors				(CSG_Parameter *pParent, const char *Identifier, const SG_Char *Name, const SG_Char *Description, CSG_Colors      *pInit = NULL);
-	CSG_Parameter *				Add_FixedTable			(CSG_Parameter *pParent, const char *Identifier, const SG_Char *Name, const SG_Char *Description, CSG_Table   *pTemplate = NULL);
+	CSG_Parameter *				Add_FixedTable			(CSG_Parameter *pParent, const char *Identifier, const SG_Char *Name, const SG_Char *Description, CSG_Table       *pInit = NULL);
 	CSG_Parameter *				Add_Grid_System			(CSG_Parameter *pParent, const char *Identifier, const SG_Char *Name, const SG_Char *Description, CSG_Grid_System *pInit = NULL);
 	CSG_Parameter *				Add_Grid				(CSG_Parameter *pParent, const char *Identifier, const SG_Char *Name, const SG_Char *Description, int Constraint, bool bSystem_Dependent = true, TSG_Data_Type Preferred_Type = SG_DATATYPE_Undefined);
 	CSG_Parameter *				Add_Grid_Output			(CSG_Parameter *pParent, const char *Identifier, const SG_Char *Name, const SG_Char *Description);
@@ -1224,7 +1475,7 @@ private:
 
 	void						_On_Construction		(void);
 
-	bool						_On_Parameter_Changed	(CSG_Parameter *pSender);
+	bool						_On_Parameter_Changed	(CSG_Parameter *pParameter, int Flags);
 
 	CSG_Parameter *				_Add_Value				(CSG_Parameter *pParent, const SG_Char *Identifier, const SG_Char *Name, const SG_Char *Description, bool bInformation, TSG_Parameter_Type Type, double Value, double Minimum, bool bMinimum, double Maximum, bool bMaximum);
 	CSG_Parameter *				_Add_Range				(CSG_Parameter *pParent, const SG_Char *Identifier, const SG_Char *Name, const SG_Char *Description, bool bInformation, double Range_Min, double Range_Max, double Minimum, bool bMinimum, double Maximum, bool bMaximum);
@@ -1233,8 +1484,10 @@ private:
 	CSG_Parameter *				_Add					(CSG_Parameter *pParent, const SG_Char *Identifier, const SG_Char *Name, const SG_Char *Description, TSG_Parameter_Type Type, int Constraint);
 	CSG_Parameter *				_Add					(CSG_Parameter *pSource);
 
-	bool						DataObjects_Create		(void);
-	bool						DataObjects_Synchronize	(void);
+	bool						DataObjects_Create			(void);
+	bool						DataObjects_Synchronize		(void);
+	bool						DataObjects_Get_Projection	(CSG_Projection &Projection)		const;
+	bool						DataObjects_Set_Projection	(const CSG_Projection &Projection);
 
 };
 
