@@ -1,3 +1,6 @@
+/**********************************************************
+ * Version $Id: pointcloud.cpp 1085 2011-06-08 08:11:35Z reklov_w $
+ *********************************************************/
 
 ///////////////////////////////////////////////////////////
 //                                                       //
@@ -110,9 +113,11 @@ CSG_PointCloud * SG_Create_PointCloud(CSG_PointCloud *pStructure)
 
 //---------------------------------------------------------
 CSG_PointCloud::CSG_PointCloud(void)
-	: CSG_Data_Object()
+	: CSG_Shapes()
 {
 	_On_Construction();
+
+	Create();
 }
 
 bool CSG_PointCloud::Create(void)
@@ -126,7 +131,7 @@ bool CSG_PointCloud::Create(void)
 
 //---------------------------------------------------------
 CSG_PointCloud::CSG_PointCloud(const CSG_PointCloud &PointCloud)
-	: CSG_Data_Object()
+	: CSG_Shapes()
 {
 	_On_Construction();
 
@@ -147,7 +152,7 @@ bool CSG_PointCloud::Create(const CSG_PointCloud &PointCloud)
 
 //---------------------------------------------------------
 CSG_PointCloud::CSG_PointCloud(const CSG_String &File_Name)
-	: CSG_Data_Object()
+	: CSG_Shapes()
 {
 	_On_Construction();
 
@@ -161,7 +166,7 @@ bool CSG_PointCloud::Create(const CSG_String &File_Name)
 
 //---------------------------------------------------------
 CSG_PointCloud::CSG_PointCloud(CSG_PointCloud *pStructure)
-	: CSG_Data_Object()
+	: CSG_Shapes()
 {
 	_On_Construction();
 
@@ -188,6 +193,9 @@ bool CSG_PointCloud::Create(CSG_PointCloud *pStructure)
 //---------------------------------------------------------
 void CSG_PointCloud::_On_Construction(void)
 {
+	m_Type			= SHAPE_TYPE_Point;
+	m_Vertex_Type	= SG_VERTEX_TYPE_XYZ;
+
 	m_nFields		= 0;
 	m_Field_Name	= NULL;
 	m_Field_Type	= NULL;
@@ -195,15 +203,25 @@ void CSG_PointCloud::_On_Construction(void)
 	m_Field_Offset	= NULL;
 
 	m_Points		= NULL;
-	m_nPoints		= 0;
-	m_nBuffer		= 0;
+	m_nRecords		= 0;
 	m_nPointBytes	= 0;
 
 	m_Cursor		= NULL;
 	m_bXYZPrecDbl	= true;
-	m_NoData_Value	= -999999;
+
+	m_Selected		= NULL;
+	m_nSelected		= 0;
+
+	Set_NoData_Value(-999999);
 
 	Set_Update_Flag();
+
+	m_Shapes.Create(SHAPE_TYPE_Point, NULL, NULL, SG_VERTEX_TYPE_XYZ);
+	m_Shapes.Add_Shape();
+	m_Shapes_Index	= -1;
+
+	m_Array_Points  .Create(sizeof(char *), 0, SG_ARRAY_GROWTH_3);
+	m_Array_Selected.Create(sizeof(int   ), 0, SG_ARRAY_GROWTH_3);
 }
 
 //---------------------------------------------------------
@@ -273,7 +291,7 @@ bool CSG_PointCloud::_Load(const CSG_String &File_Name)
 		return( false );
 	}
 
-	if( !Stream.Read(&nPointBytes, sizeof(int)) || nPointBytes < 3 * sizeof(float) )
+	if( !Stream.Read(&nPointBytes, sizeof(int)) || nPointBytes < (int)(3 * sizeof(float)) )
 	{
 		SG_UI_Msg_Add(LNG("[MSG] failed"), false, SG_UI_MSG_STYLE_FAILURE);
 		SG_UI_Msg_Add_Error(LNG("[ERR] incompatible file."));
@@ -329,7 +347,7 @@ bool CSG_PointCloud::_Load(const CSG_String &File_Name)
 		}
 	}
 
-	if( m_nPointBytes != nPointBytes )
+	if( m_nPointBytes != nPointBytes + 1 )
 	{
 		SG_UI_Msg_Add(LNG("[MSG] failed"), false, SG_UI_MSG_STYLE_FAILURE);
 		SG_UI_Msg_Add_Error(LNG("[ERR] incompatible file."));
@@ -338,9 +356,9 @@ bool CSG_PointCloud::_Load(const CSG_String &File_Name)
 	}
 
 	//-----------------------------------------------------
-	int		fLength	= Stream.Length();
+	long		fLength	= Stream.Length();
 
-	while( _Inc_Array() && Stream.Read(m_Cursor, m_nPointBytes) && SG_UI_Process_Set_Progress(Stream.Tell(), fLength) )
+	while( _Inc_Array() && Stream.Read(m_Cursor + 1, nPointBytes) && SG_UI_Process_Set_Progress(Stream.Tell(), fLength) )
 	{}
 
 	_Dec_Array();
@@ -349,7 +367,7 @@ bool CSG_PointCloud::_Load(const CSG_String &File_Name)
 
 	Load_MetaData(File_Name);
 
-	if( m_nPoints <= 0 )
+	if( 0 > Get_Count() )
 	{
 		SG_UI_Msg_Add(LNG("[MSG] failed"), false, SG_UI_MSG_STYLE_FAILURE);
 		SG_UI_Msg_Add_Error(LNG("[ERR] no records in file."));
@@ -357,6 +375,8 @@ bool CSG_PointCloud::_Load(const CSG_String &File_Name)
 		return( false );
 	}
 
+	Get_Projection().Load(SG_File_Make_Path(NULL, File_Name, SG_T("prj")), SG_PROJ_FMT_WKT);
+
 	SG_UI_Msg_Add(LNG("[MSG] okay"), false, SG_UI_MSG_STYLE_SUCCESS);
 
 	return( true );
@@ -369,7 +389,9 @@ bool CSG_PointCloud::_Save(const CSG_String &File_Name)
 
 	SG_UI_Msg_Add(CSG_String::Format(SG_T("%s: %s..."), LNG("[MSG] Save point cloud"), File_Name.c_str()), true);
 
-	if( Stream.Open(File_Name, SG_FILE_W, true) == false )
+	CSG_String	sFile_Name = SG_File_Make_Path(NULL, File_Name, SG_T("spc"));
+
+	if( Stream.Open(sFile_Name, SG_FILE_W, true) == false )
 	{
 		SG_UI_Msg_Add(LNG("[MSG] failed"), false, SG_UI_MSG_STYLE_FAILURE);
 		SG_UI_Msg_Add_Error(LNG("[ERR] unable to create file."));
@@ -377,32 +399,36 @@ bool CSG_PointCloud::_Save(const CSG_String &File_Name)
 		return( false );
 	}
 
-	int		i, iBuffer;
+	int		i, iBuffer, nPointBytes	= m_nPointBytes - 1;
 
 	Stream.Write((void *)POINTCLOUD_FILE_VERSION, 6);
-	Stream.Write(&m_nPointBytes	, sizeof(int));
+	Stream.Write(&nPointBytes	, sizeof(int));
 	Stream.Write(&m_nFields		, sizeof(int));
 
 	for(i=0; i<m_nFields; i++)
 	{
 		Stream.Write(&m_Field_Type[i], sizeof(TSG_Data_Type));
 
-		iBuffer	= m_Field_Name[i]->Length();	if( iBuffer >= 1024 - 1 )	iBuffer	= 1024 - 1;
+		iBuffer	= (int)m_Field_Name[i]->Length();	if( iBuffer >= 1024 - 1 )	iBuffer	= 1024 - 1;
 		Stream.Write(&iBuffer, sizeof(int));
 		Stream.Write((void *)m_Field_Name[i]->b_str(), sizeof(char), iBuffer);
 	}
 
-	for(i=0; i<m_nPoints && SG_UI_Process_Set_Progress(i, m_nPoints); i++)
+	_Set_Shape(m_Shapes_Index);
+
+	for(i=0; i<Get_Count() && SG_UI_Process_Set_Progress(i, Get_Count()); i++)
 	{
-		Stream.Write(m_Points[i], m_nPointBytes);
+		Stream.Write(m_Points[i] + 1, nPointBytes);
 	}
 
 	Set_Modified(false);
 
-	Set_File_Name(SG_File_Make_Path(NULL, File_Name, SG_T("spc")));
+	Set_File_Name(sFile_Name);
 
 	Save_MetaData(File_Name);
 
+	Get_Projection().Save(SG_File_Make_Path(NULL, File_Name, SG_T("prj")), SG_PROJ_FMT_WKT);
+
 	SG_UI_Msg_Add(LNG("[MSG] okay"), false, SG_UI_MSG_STYLE_SUCCESS);
 
 	return( true );
@@ -436,11 +462,11 @@ bool CSG_PointCloud::Assign(CSG_Data_Object *pObject)
 			_Add_Field(pPointCloud->m_Field_Name[iField]->c_str(), pPointCloud->m_Field_Type[iField]);
 		}
 
-		for(int iPoint=0; iPoint<pPointCloud->m_nPoints; iPoint++)
+		for(int iPoint=0; iPoint<pPointCloud->Get_Count(); iPoint++)
 		{
 			if( _Inc_Array() )
 			{
-				memcpy(m_Points[iPoint], pPointCloud->m_Points[iPoint], m_nPointBytes);
+				memcpy(m_Points[iPoint] + 1, pPointCloud->m_Points[iPoint] + 1, m_nPointBytes - 1);
 			}
 		}
 
@@ -484,9 +510,9 @@ bool CSG_PointCloud::is_Compatible(CSG_PointCloud *pPointCloud) const
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-bool CSG_PointCloud::_Add_Field(const SG_Char *Name, TSG_Data_Type Type)
+bool CSG_PointCloud::_Add_Field(const SG_Char *Name, TSG_Data_Type Type, int iField)
 {
-	if( SG_Data_Type_Get_Size(Type) <= 0 )
+	if( !Name || SG_Data_Type_Get_Size(Type) <= 0 )
 	{
 		return( false );
 	}
@@ -499,41 +525,102 @@ bool CSG_PointCloud::_Add_Field(const SG_Char *Name, TSG_Data_Type Type)
 	m_Field_Name  [m_nFields]	= new CSG_String(Name);
 	m_Field_Type  [m_nFields]	= Type;
 	m_Field_Stats [m_nFields]	= new CSG_Simple_Statistics();
-	m_Field_Offset[m_nFields]	= m_nFields == 0 ? 0 : m_Field_Offset[m_nFields - 1] + SG_Data_Type_Get_Size(m_Field_Type[m_nFields - 1]);
+	m_Field_Offset[m_nFields]	= m_nFields == 0 ? 1 : m_Field_Offset[m_nFields - 1] + (int)SG_Data_Type_Get_Size(m_Field_Type[m_nFields - 1]);
 
-	m_nPointBytes	+= SG_Data_Type_Get_Size(m_Field_Type[m_nFields]);
+	if( m_nFields == 0 )
+	{
+		m_nPointBytes	= 1;
+	}
+
+	m_nPointBytes	+= (int)SG_Data_Type_Get_Size(m_Field_Type[m_nFields]);
 	m_nFields		++;
 
+	m_Shapes.Add_Field(Name, Type);
+
+	for(int i=0; i<Get_Count(); i++)
+	{
+		m_Points[i]	= (char *)SG_Realloc(m_Points[i], m_nPointBytes * sizeof(char));
+	}
+
+	Set_Modified();
+
 	return( true );
 }
 
 //---------------------------------------------------------
-bool CSG_PointCloud::Add_Field(const SG_Char *Name, TSG_Data_Type Type)
+bool CSG_PointCloud::Add_Field(const SG_Char *Name, TSG_Data_Type Type, int iField)
 {
-	if( m_nPoints == 0 )
+	if( m_nFields == 0 )
 	{
-		if( m_nFields == 0 )
-		{
-			_Add_Field(SG_T("X"), m_bXYZPrecDbl ? SG_DATATYPE_Double : SG_DATATYPE_Float);
-			_Add_Field(SG_T("Y"), m_bXYZPrecDbl ? SG_DATATYPE_Double : SG_DATATYPE_Float);
-			_Add_Field(SG_T("Z"), m_bXYZPrecDbl ? SG_DATATYPE_Double : SG_DATATYPE_Float);
-		}
-
-		if( Name && SG_Data_Type_Get_Size(Type) > 0 )
-		{
-			return( _Add_Field(Name, Type) );
-		}
+		_Add_Field(SG_T("X"), m_bXYZPrecDbl ? SG_DATATYPE_Double : SG_DATATYPE_Float);
+		_Add_Field(SG_T("Y"), m_bXYZPrecDbl ? SG_DATATYPE_Double : SG_DATATYPE_Float);
+		_Add_Field(SG_T("Z"), m_bXYZPrecDbl ? SG_DATATYPE_Double : SG_DATATYPE_Float);
 	}
 
-	return( false );
+	return( _Add_Field(Name, Type, iField) );
 }
 
 //---------------------------------------------------------
 #ifdef _SAGA_UNICODE
-bool CSG_PointCloud::Add_Field(const char *Name, TSG_Data_Type Type)
-{	return( Add_Field(CSG_String(Name), Type) );	}
+bool CSG_PointCloud::Add_Field(const char *Name, TSG_Data_Type Type, int iField)
+{	return( Add_Field(CSG_String(Name), Type, iField) );	}
 #endif
 
+//---------------------------------------------------------
+bool CSG_PointCloud::Del_Field(int iField)
+{
+	int		i;
+
+	if( iField < 3 || iField >= m_nFields )
+	{
+		return( false );
+	}
+
+	if( m_nFields == 1 )
+	{
+		return( Destroy() );
+	}
+
+	//-----------------------------------------------------
+	m_nFields		--;
+	m_nPointBytes	-= (int)SG_Data_Type_Get_Size(m_Field_Type[iField]);
+
+	for(i=0; i<m_nRecords; i++)
+	{
+		if( iField < m_nFields )
+		{
+			memmove(
+				m_Points[i] + m_Field_Offset[iField],
+				m_Points[i] + m_Field_Offset[iField + 1],
+				m_Field_Offset[iField + 1] - m_Field_Offset[iField]
+			);
+		}
+
+		m_Points[i]	= (char *)SG_Realloc(m_Points[i], m_nPointBytes * sizeof(char));
+	}
+
+	//-----------------------------------------------------
+	delete(m_Field_Name [iField]);
+	delete(m_Field_Stats[iField]);
+
+	for(i=iField; i<m_nFields; i++)
+	{
+		m_Field_Name  [i]	= m_Field_Name  [i + 1];
+		m_Field_Type  [i]	= m_Field_Type  [i + 1];
+		m_Field_Stats [i]	= m_Field_Stats [i + 1];
+		m_Field_Offset[i]	= m_Field_Offset[i - 1] + (int)SG_Data_Type_Get_Size(m_Field_Type[i - 1]);
+	}
+
+	m_Field_Name	= (CSG_String            **)SG_Realloc(m_Field_Name  , m_nFields * sizeof(CSG_String *));
+	m_Field_Type	= (TSG_Data_Type          *)SG_Realloc(m_Field_Type  , m_nFields * sizeof(TSG_Data_Type));
+	m_Field_Stats	= (CSG_Simple_Statistics **)SG_Realloc(m_Field_Stats , m_nFields * sizeof(CSG_Simple_Statistics *));
+	m_Field_Offset	= (int                    *)SG_Realloc(m_Field_Offset, m_nFields * sizeof(int));
+
+	Set_Modified();
+
+	return( true );
+}
+
 //---------------------------------------------------------
 bool CSG_PointCloud::_Set_Field_Value(char *pPoint, int iField, double Value)
 {
@@ -556,6 +643,8 @@ bool CSG_PointCloud::_Set_Field_Value(char *pPoint, int iField, double Value)
 		case SG_DATATYPE_Double:	*((double *)pPoint)	= (double)Value;	break;
 		}
 
+		m_Field_Stats[iField]->Invalidate();
+
 		return( true );
 	}
 
@@ -587,6 +676,36 @@ double CSG_PointCloud::_Get_Field_Value(char *pPoint, int iField) const
 	return( 0.0 );
 }
 
+//---------------------------------------------------------
+bool CSG_PointCloud::Set_Value(int iPoint, int iField, const SG_Char *Value)
+{
+	if( iPoint >= 0 && iPoint < m_nRecords && Value && *Value )
+	{
+		double		d;
+		CSG_String	s(Value);
+
+		if( s.asDouble(d) )
+		{
+			return( _Set_Field_Value(m_Points[iPoint], iField, d) );
+		}
+	}
+
+	return( false );
+}
+
+//---------------------------------------------------------
+bool CSG_PointCloud::Get_Value(int iPoint, int iField, CSG_String &Value)	const
+{
+	if( iPoint >= 0 && iPoint < m_nRecords && iField >= 0 && iField < m_nFields )
+	{
+		Value.Printf(SG_T("%f"), _Get_Field_Value(m_Points[iPoint], iField));
+
+		return( true );
+	}
+
+	return( false );
+}
+
 
 ///////////////////////////////////////////////////////////
 //														 //
@@ -595,9 +714,9 @@ double CSG_PointCloud::_Get_Field_Value(char *pPoint, int iField) const
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-TSG_Point_3D CSG_PointCloud::Get_Point(void)	const
+TSG_Point_Z CSG_PointCloud::Get_Point(void)	const
 {
-	TSG_Point_3D	p;
+	TSG_Point_Z	p;
 
 	if( m_Cursor )
 	{
@@ -614,11 +733,11 @@ TSG_Point_3D CSG_PointCloud::Get_Point(void)	const
 }
 
 //---------------------------------------------------------
-TSG_Point_3D CSG_PointCloud::Get_Point(int iPoint)	const
+TSG_Point_Z CSG_PointCloud::Get_Point(int iPoint)	const
 {
-	TSG_Point_3D	p;
+	TSG_Point_Z	p;
 
-	if( iPoint >= 0 && iPoint < m_nPoints )
+	if( iPoint >= 0 && iPoint < Get_Count() )
 	{
 		char	*pPoint	= m_Points[iPoint];
 
@@ -635,19 +754,14 @@ TSG_Point_3D CSG_PointCloud::Get_Point(int iPoint)	const
 }
 
 //---------------------------------------------------------
-bool CSG_PointCloud::Set_NoData_Value(double NoData_Value)
+bool CSG_PointCloud::On_NoData_Changed(void)
 {
-	if( NoData_Value != m_NoData_Value )
+	for(int i=3; i<m_nFields; i++)
 	{
-		for(int i=3; i<m_nFields; i++)
-		{
-			m_Field_Stats[i]->Invalidate();
-		}
-
-		return( true );
+		m_Field_Stats[i]->Invalidate();
 	}
 
-	return( false );
+	return( true );
 }
 
 
@@ -667,9 +781,7 @@ bool CSG_PointCloud::Add_Point(double x, double y, double z)
 		_Set_Field_Value(m_Cursor, 2, z);
 
 		Set_Modified();
-
 		Set_Update_Flag();
-
 		_Stats_Invalidate();
 
 		return( true );
@@ -681,24 +793,29 @@ bool CSG_PointCloud::Add_Point(double x, double y, double z)
 //---------------------------------------------------------
 bool CSG_PointCloud::Del_Point(int iPoint)
 {
-	if( iPoint >= 0 && iPoint < m_nPoints )
+	if( iPoint >= 0 && iPoint < Get_Count() )
 	{
-		m_Cursor	= NULL;
-
-		delete(m_Points[iPoint]);
-
-		m_nPoints--;
-
-		for(int i=iPoint, j=iPoint+1; i<m_nPoints; i++, j++)
+		if( is_Selected(iPoint) )
 		{
-			m_Points[i]	= m_Points[i + 1];
+			Select(iPoint, true);
 		}
 
+		m_Cursor	= m_Points[iPoint];
+
+		for(int i=iPoint, j=iPoint+1; j<Get_Count(); i++, j++)
+		{
+			m_Points[i]	= m_Points[j];
+		}
+
+		m_Points[Get_Count() - 1]	= m_Cursor;
+
+		m_Cursor	= NULL;
+
 		_Dec_Array();
 
 		Set_Modified();
-
 		Set_Update_Flag();
+		_Stats_Invalidate();
 
 		return( true );
 	}
@@ -709,23 +826,22 @@ bool CSG_PointCloud::Del_Point(int iPoint)
 //---------------------------------------------------------
 bool CSG_PointCloud::Del_Points(void)
 {
-	if( m_nBuffer > 0 )
+	for(int iPoint=0; iPoint<m_nRecords; iPoint++)
 	{
-		for(int iPoint=0; iPoint<m_nPoints; iPoint++)
-		{
-			SG_Free(m_Points[iPoint]);
-		}
-
-		SG_Free(m_Points);
-		m_Points	= NULL;
-		m_nPoints	= 0;
-		m_nBuffer	= 0;
-		m_Cursor	= NULL;
-
-		return( true );
+		SG_Free(m_Points[iPoint]);
 	}
 
-	return( false );
+	m_Array_Points  .Destroy();
+	m_Array_Selected.Destroy();
+
+	m_nRecords	= 0;
+	m_Points	= NULL;
+	m_Cursor	= NULL;
+
+	m_nSelected	= 0;
+	m_Selected	= NULL;
+
+	return( true );
 }
 
 
@@ -735,31 +851,12 @@ bool CSG_PointCloud::Del_Points(void)
 //														 //
 ///////////////////////////////////////////////////////////
 
-//---------------------------------------------------------
-#define GET_GROW_SIZE(n)	(n < 256 ? 1 : (n < 8192 ? 128 : 1024))
-
 //---------------------------------------------------------
 bool CSG_PointCloud::_Inc_Array(void)
 {
-	if( m_nFields > 0 )
+	if( m_nFields > 0 && m_Array_Points.Set_Array(m_nRecords + 1, (void **)&m_Points) )
 	{
-		if( (m_nPoints + 1) >= m_nBuffer )
-		{
-			char	**pPoints	= (char **)SG_Realloc(m_Points, (m_nBuffer + GET_GROW_SIZE(m_nBuffer)) * sizeof(char *));
-
-			if( pPoints )
-			{
-				m_Points	= pPoints;
-				m_nBuffer	+= GET_GROW_SIZE(m_nBuffer);
-			}
-			else
-			{
-				return( false );
-			}
-		}
-
-		m_Cursor	= m_Points[m_nPoints]	= (char *)SG_Calloc(m_nPointBytes, sizeof(char));
-		m_nPoints	++;
+		m_Points[m_nRecords++]	= m_Cursor	= (char *)SG_Calloc(m_nPointBytes, sizeof(char));
 
 		return( true );
 	}
@@ -770,25 +867,15 @@ bool CSG_PointCloud::_Inc_Array(void)
 //---------------------------------------------------------
 bool CSG_PointCloud::_Dec_Array(void)
 {
-	if( m_nPoints > 0 )
+	if( m_nRecords > 0 )
 	{
-		_Stats_Invalidate();
+		m_nRecords	--;
 
 		m_Cursor	= NULL;
-		m_nPoints	--;
 
-		SG_Free(m_Points[m_nPoints]);
+		SG_Free(m_Points[m_nRecords]);
 
-		if( (m_nPoints - 1) < m_nBuffer - GET_GROW_SIZE(m_nBuffer) )
-		{
-			char	**pPoints	= (char **)SG_Realloc(m_Points, (m_nBuffer - GET_GROW_SIZE(m_nBuffer)) * sizeof(char *));
-
-			if( pPoints )
-			{
-				m_Points	= pPoints;
-				m_nBuffer	-= GET_GROW_SIZE(m_nBuffer);
-			}
-		}
+		m_Array_Points.Set_Array(m_nRecords, (void **)&m_Points);
 	}
 
 	return( true );
@@ -802,10 +889,12 @@ bool CSG_PointCloud::_Dec_Array(void)
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-const CSG_Rect & CSG_PointCloud::Get_Extent(void)
+bool CSG_PointCloud::On_Update(void)
 {
 	if( m_nFields >= 2 )
 	{
+		_Set_Shape(m_Shapes_Index);
+
 		_Stats_Update(0);
 		_Stats_Update(1);
 
@@ -815,47 +904,23 @@ const CSG_Rect & CSG_PointCloud::Get_Extent(void)
 		);
 	}
 
-	return( m_Extent );
-}
-
-//---------------------------------------------------------
-bool CSG_PointCloud::_Stats_Invalidate(void) const
-{
-	for(int iField=0; iField<m_nFields; iField++)
-	{
-		_Stats_Invalidate(iField);
-	}
-
 	return( true );
 }
 
-//---------------------------------------------------------
-bool CSG_PointCloud::_Stats_Invalidate(int iField) const
-{
-	if( iField >= 0 && iField < m_nFields )
-	{
-		m_Field_Stats[iField]->Invalidate();
-
-		return( true );
-	}
-
-	return( false );
-}
-
 //---------------------------------------------------------
 bool CSG_PointCloud::_Stats_Update(int iField) const
 {
-	if( iField >= 0 && iField < m_nFields && m_nPoints > 0 )
+	if( iField >= 0 && iField < m_nFields && Get_Count() > 0 )
 	{
 		if( !m_Field_Stats[iField]->is_Evaluated() )
 		{
 			char	**pPoint	= m_Points;
 
-			for(int iPoint=0; iPoint<m_nPoints; iPoint++, pPoint++)
+			for(int iPoint=0; iPoint<Get_Count(); iPoint++, pPoint++)
 			{
 				double	Value	= _Get_Field_Value(*pPoint, iField);
 
-				if( iField < 3 || Value != m_NoData_Value )
+				if( iField < 3 || is_NoData_Value(Value) == false )
 				{
 					m_Field_Stats[iField]->Add_Value(Value);
 				}
@@ -869,6 +934,363 @@ bool CSG_PointCloud::_Stats_Update(int iField) const
 }
 
 
+///////////////////////////////////////////////////////////
+//														 //
+//														 //
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+CSG_Shape * CSG_PointCloud::_Set_Shape(int iPoint)
+{
+	SG_UI_Progress_Lock(true);
+
+	CSG_Shape	*pShape	= m_Shapes.Get_Shape(0);
+
+	if( pShape->is_Modified() && m_Shapes_Index >= 0 && m_Shapes_Index < Get_Count() )
+	{
+		m_Cursor	= m_Points[m_Shapes_Index];
+
+		for(int i=0; i<Get_Field_Count(); i++)
+		{
+			Set_Value(i, pShape->asDouble(i));
+		}
+
+		Set_Value(0, pShape->Get_Point(0).x);
+		Set_Value(1, pShape->Get_Point(0).y);
+		Set_Value(2, pShape->Get_Z(0));
+	}
+
+	if( iPoint >= 0 && iPoint < Get_Count() )
+	{
+		if( iPoint != m_Shapes_Index )
+		{
+			m_Cursor	= m_Points[iPoint];
+
+			pShape->Set_Point(Get_X(), Get_Y(), 0, 0);
+			pShape->Set_Z    (Get_Z()         , 0, 0);
+
+			for(int i=0; i<Get_Field_Count(); i++)
+			{
+				pShape->Set_Value(i, Get_Value(i));
+			}
+
+			m_Shapes_Index	= iPoint;
+		}
+
+		m_Shapes.Set_Modified(false);
+
+		SG_UI_Progress_Lock(false);
+
+		return( pShape );
+	}
+
+	m_Shapes_Index	= -1;
+
+	SG_UI_Progress_Lock(false);
+
+	return( NULL );
+}
+
+//---------------------------------------------------------
+CSG_Table_Record * CSG_PointCloud::Get_Record(int iRecord)	const
+{
+	return( ((CSG_PointCloud *)this)->_Set_Shape(iRecord) );
+}
+
+
+///////////////////////////////////////////////////////////
+//														 //
+//														 //
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+CSG_Shape * CSG_PointCloud::Get_Shape(TSG_Point Point, double Epsilon)
+{
+	CSG_Rect	r(Point.x - Epsilon, Point.y - Epsilon, Point.x + Epsilon, Point.y + Epsilon);
+
+	if( r.Intersects(Get_Extent()) != INTERSECTION_None )
+	{
+		int		iPoint		= -1;
+		double	iDistance	= -1.0;
+
+		for(int iRecord=0; iRecord<Get_Count(); iRecord++)
+		{
+			Set_Cursor(iRecord);
+
+			if( r.Contains(Get_X(), Get_Y()) )
+			{
+				if( iPoint < 0 || iDistance > SG_Get_Distance(Point.x, Point.y, Get_X(), Get_Y()) )
+				{
+					iPoint		= iRecord;
+					iDistance	= SG_Get_Distance(Point.x, Point.y, Get_X(), Get_Y());
+				}
+			}
+		}
+
+		if( iPoint >= 0 )
+		{
+			return( CSG_Shapes::Get_Shape(iPoint) );
+		}
+	}
+
+	return( NULL );
+}
+
+//---------------------------------------------------------
+CSG_Table_Record * CSG_PointCloud::Ins_Record(int iRecord, CSG_Table_Record *pCopy)
+{
+	return( NULL );
+}
+
+//---------------------------------------------------------
+CSG_Table_Record * CSG_PointCloud::Add_Record(CSG_Table_Record *pCopy)
+{
+	return( NULL );
+}
+
+//---------------------------------------------------------
+CSG_Shape * CSG_PointCloud::Add_Shape(CSG_Table_Record *pCopy, TSG_ADD_Shape_Copy_Mode mCopy)
+{
+	Add_Point(0.0, 0.0, 0.0);
+
+	if( pCopy && (mCopy == SHAPE_COPY_ATTR || mCopy == SHAPE_COPY) )
+	{
+		for(int iField=0; iField<Get_Field_Count() && iField<pCopy->Get_Table()->Get_Field_Count(); iField++)
+		{
+			if( Get_Field_Type(iField) == pCopy->Get_Table()->Get_Field_Type(iField) )
+			{
+				Set_Value(iField, pCopy->asDouble(iField));
+			}
+		}
+	}
+
+	return( _Set_Shape(Get_Count() - 1) );
+}
+
+
+///////////////////////////////////////////////////////////
+//														 //
+//														 //
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+bool CSG_PointCloud::Select(int iRecord, bool bInvert)
+{
+	if( !bInvert )
+	{
+		for(int i=0; i<m_nSelected; i++)
+		{
+			m_Points[m_Selected[i]][0]	&= ~SG_TABLE_REC_FLAG_Selected;
+		}
+
+		m_Array_Selected.Destroy();
+		m_Selected	= NULL;
+		m_nSelected	= 0;
+	}
+
+	if( Set_Cursor(iRecord) )
+	{
+		if( (m_Cursor[0] & SG_TABLE_REC_FLAG_Selected) == 0 )	// select
+		{
+			if( m_Array_Selected.Set_Array(m_nSelected + 1, (void **)&m_Selected) )
+			{
+				m_Cursor[0]	|= SG_TABLE_REC_FLAG_Selected;
+
+				m_Selected[m_nSelected++]	= iRecord;
+
+				return( true );
+			}
+		}
+		else													// deselect
+		{
+			m_Cursor[0]	&= ~SG_TABLE_REC_FLAG_Selected;
+
+			m_nSelected--;
+
+			for(int i=0; i<m_nSelected; i++)
+			{
+				if( m_Points[iRecord] == m_Points[m_Selected[i]] )
+				{
+					for(; i<m_nSelected; i++)
+					{
+						m_Selected[i]	= m_Selected[i + 1];
+					}
+				}
+			}
+
+			m_Array_Selected.Set_Array(m_nSelected, (void **)&m_Selected);
+
+			return( true );
+		}
+	}
+
+	return( false );
+}
+
+//---------------------------------------------------------
+bool CSG_PointCloud::Select(CSG_Shape *pShape, bool bInvert)
+{
+	return( false );
+}
+
+//---------------------------------------------------------
+bool CSG_PointCloud::Select(TSG_Rect Extent, bool bInvert)
+{
+	if( !bInvert )	// clear selection
+	{
+		Select(-1, false);
+	}
+
+	if( Get_Extent().Intersects(Extent) != INTERSECTION_None )
+	{
+		for(int i=0; i<Get_Count(); i++)
+		{
+			Set_Cursor(i);
+
+			if(	Extent.xMin <= Get_X() && Get_X() <= Extent.xMax
+			&&	Extent.yMin <= Get_Y() && Get_Y() <= Extent.yMax )
+			{
+				Select(i, true);
+			}
+		}
+	}
+
+	return( m_nSelected > 0 );
+}
+
+//---------------------------------------------------------
+bool CSG_PointCloud::Select(TSG_Point Point, bool bInvert)
+{
+	CSG_Rect	r(Point.x, Point.y, Point.x, Point.y);
+
+	return( Select(r.m_rect, bInvert) );
+}
+
+
+///////////////////////////////////////////////////////////
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+bool CSG_PointCloud::is_Selected(int iRecord)	const
+{
+	return( iRecord >= 0 && iRecord < Get_Count() && (m_Points[iRecord][0] & SG_TABLE_REC_FLAG_Selected) != 0 );
+}
+
+
+///////////////////////////////////////////////////////////
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+CSG_Shape * CSG_PointCloud::Get_Selection(int Index)
+{
+	return( Index >= 0 && Index < m_nSelected ? _Set_Shape(m_Selected[Index]) : NULL );
+}
+
+//---------------------------------------------------------
+const CSG_Rect & CSG_PointCloud::Get_Selection_Extent(void)
+{
+	if( m_nSelected > 0 && Set_Cursor(m_Selected[0]) )
+	{
+		TSG_Rect	r;
+
+		r.xMin	= r.xMax	= Get_X();
+		r.yMin	= r.yMax	= Get_Y();
+
+		for(int i=1; i<m_nSelected; i++)
+		{
+			if( Set_Cursor(m_Selected[i]) )
+			{
+				if( Get_X() < r.xMin )	r.xMin	= Get_X();	else if( Get_X() > r.xMax )	r.xMax	= Get_X();
+				if( Get_Y() < r.yMin )	r.yMin	= Get_Y();	else if( Get_Y() > r.yMax )	r.yMax	= Get_Y();
+			}
+		}
+
+		m_Extent_Selected.Assign(r);
+	}
+	else
+	{
+		m_Extent_Selected.Assign(0.0, 0.0, 0.0, 0.0);
+	}
+
+	return( m_Extent_Selected );
+}
+
+
+///////////////////////////////////////////////////////////
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+int CSG_PointCloud::Del_Selection(void)
+{
+	if( m_nSelected <= 0 )
+	{
+		return( 0 );
+	}
+
+	//-----------------------------------------------------
+	int		i, n;
+
+	m_Array_Selected.Set_Array(0, (void **)&m_Selected);
+	m_nSelected	= 0;
+	m_Cursor	= NULL;
+
+	for(i=0, n=0; i<m_nRecords; i++)
+	{
+		if( (m_Points[i][0] & SG_TABLE_REC_FLAG_Selected) != 0 )
+		{
+			SG_Free(m_Points[i]);
+		}
+		else
+		{
+			if( n < i )
+			{
+				m_Points[n]	= m_Points[i];
+			}
+
+			n++;
+		}
+	}
+
+	m_Array_Points.Set_Array(m_nRecords = n, (void **)&m_Points);
+
+	return( n );
+}
+
+//---------------------------------------------------------
+int CSG_PointCloud::Inv_Selection(void)
+{
+	char	**pPoint;
+	int		i, n;
+
+	n	= m_nRecords - m_nSelected;
+
+	if( m_Array_Selected.Set_Array(n, (void **)&m_Selected) )
+	{
+		for(i=0, m_nSelected=0, pPoint=m_Points; i<m_nRecords; i++, pPoint++)
+		{
+			if( ((*pPoint)[0] & SG_TABLE_REC_FLAG_Selected) == 0 && m_nSelected < n )
+			{
+				m_Selected[m_nSelected++]	= i;
+
+				(*pPoint)[0]	|= SG_TABLE_REC_FLAG_Selected;
+			}
+			else
+			{
+				(*pPoint)[0]	&= ~SG_TABLE_REC_FLAG_Selected;
+			}
+		}
+	}
+
+	return( m_nSelected );
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 //														 //
