@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: pointcloud.h 911 2011-02-14 16:38:15Z reklov_w $
+ * Version $Id: pointcloud.h 1167 2011-09-21 08:45:40Z reklov_w $
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -142,8 +142,8 @@ public:
 	double							Get_Z				(void)			const		{	return( _Get_Field_Value(m_Cursor, 2) );				}
 	bool							Set_Attribute		(int iField, double Value)	{	return( Set_Value(iField + 3, Value) );					}
 	double							Get_Attribute		(int iField)	const		{	return( Get_Value(iField + 3) );						}
-	bool							Set_NoData			(int iField)				{	return( Set_Attribute(iField, Get_NoData_Value()) );	}
-	bool							is_NoData			(int iField)	const		{	return( is_NoData_Value(Get_Attribute(iField)) );		}
+	bool							Set_NoData			(int iField)				{	return( Set_Value(iField, Get_NoData_Value()) );	}
+	bool							is_NoData			(int iField)	const		{	return( is_NoData_Value(Get_Value(iField)) );		}
 
 	virtual bool					Set_Value			(int iPoint, int iField, double Value)	{	return( _Set_Field_Value(iPoint >= 0 && iPoint < m_nRecords ? m_Points[iPoint] : NULL, iField, Value) );	}
 	virtual double					Get_Value			(int iPoint, int iField)	const		{	return( _Get_Field_Value(iPoint >= 0 && iPoint < m_nRecords ? m_Points[iPoint] : NULL, iField) );		}
@@ -152,8 +152,8 @@ public:
 	double							Get_Z				(int iPoint)				const		{	return( _Get_Field_Value(iPoint >= 0 && iPoint < m_nRecords ? m_Points[iPoint] : NULL, 2) );				}
 	bool							Set_Attribute		(int iPoint, int iField, double Value)	{	return( Set_Value(iPoint, iField + 3, Value) );				}
 	double							Get_Attribute		(int iPoint, int iField)	const		{	return( Get_Value(iPoint, iField + 3) );					}
-	bool							Set_NoData			(int iPoint, int iField)				{	return( Set_Attribute(iPoint, iField, Get_NoData_Value()) );}
-	bool							is_NoData			(int iPoint, int iField)	const		{	return( is_NoData_Value(Get_Attribute(iPoint, iField)) );	}
+	bool							Set_NoData			(int iPoint, int iField)				{	return( Set_Value(iPoint, iField, Get_NoData_Value()) );}
+	bool							is_NoData			(int iPoint, int iField)	const		{	return( is_NoData_Value(Get_Value(iPoint, iField)) );	}
 
 	virtual bool					Set_Value			(int iPoint, int iField, const SG_Char *Value);
 	virtual bool					Get_Value			(int iPoint, int iField, CSG_String    &Value)	const;
