@@ -1,3 +1,6 @@
+/**********************************************************
+ * Version $Id: shapes.h 1230 2011-11-22 11:12:10Z oconrad $
+ *********************************************************/
 ///////////////////////////////////////////////////////////
 //                                                       //
 //                         SAGA                          //
@@ -79,10 +82,19 @@
 //														 //
 ///////////////////////////////////////////////////////////
 
+//---------------------------------------------------------
+typedef enum ESG_Vertex_Type
+{
+	SG_VERTEX_TYPE_XY		= 0,
+	SG_VERTEX_TYPE_XYZ,
+	SG_VERTEX_TYPE_XYZM
+}
+TSG_Vertex_Type;
+
 //---------------------------------------------------------
 typedef enum ESG_Shape_Type
 {
-	SHAPE_TYPE_Undefined		= 0,
+	SHAPE_TYPE_Undefined	= 0,
 	SHAPE_TYPE_Point,
 	SHAPE_TYPE_Points,
 	SHAPE_TYPE_Line,
@@ -133,20 +145,34 @@ public:
 	virtual int					Get_Part_Count		(void)											= 0;
 	virtual int					Get_Point_Count		(void);
 	virtual int					Get_Point_Count		(int iPart)										= 0;
-	virtual TSG_Point			Get_Point			(int iPoint, int iPart = 0)						= 0;
+	virtual TSG_Point			Get_Point			(int iPoint, int iPart = 0, bool bAscending = true)	= 0;
 
+	virtual void				Set_Z				(double z, int iPoint, int iPart = 0)				{		}
+	virtual double				Get_Z				(int iPoint, int iPart = 0, bool bAscending = true)	{	return( 0.0 );	}
+	virtual double				Get_ZMin			(void)												{	return( 0.0 );	}
+	virtual double				Get_ZMax			(void)												{	return( 0.0 );	}
+
+	virtual void				Set_M				(double m, int iPoint, int iPart = 0)				{		}
+	virtual double				Get_M				(int iPoint, int iPart = 0, bool bAscending = true)	{	return( 0.0 );	}
+	virtual double				Get_MMin			(void)												{	return( 0.0 );	}
+	virtual double				Get_MMax			(void)												{	return( 0.0 );	}
 
 	//-----------------------------------------------------
 	virtual const CSG_Rect &	Get_Extent			(void)											= 0;
 	virtual const CSG_Rect &	Get_Extent			(int iPart)	{	return( Get_Extent() );		}
 
-	int							Intersects			(TSG_Rect Extent);
+	virtual TSG_Point			Get_Centroid		(void)											= 0;
+
+	TSG_Intersection			Intersects			(CSG_Shape *pShape);
+	TSG_Intersection			Intersects			(TSG_Rect Extent);
 
 	virtual double				Get_Distance		(TSG_Point Point)								= 0;
 	virtual double				Get_Distance		(TSG_Point Point, int iPart)					= 0;
 	virtual double				Get_Distance		(TSG_Point Point, TSG_Point &Next)				= 0;
 	virtual double				Get_Distance		(TSG_Point Point, TSG_Point &Next, int iPart)	= 0;
 
+	virtual bool				Revert_Points		(int iPart)	{	return( true );	}
+
 
 protected:
 
@@ -154,7 +180,8 @@ protected:
 	virtual ~CSG_Shape(void);
 
 	virtual bool				On_Assign			(CSG_Shape *pShape)								= 0;
-	virtual int					On_Intersects		(TSG_Rect Extent)								= 0;
+	virtual TSG_Intersection	On_Intersects		(CSG_Shape *pShape)								= 0;
+	virtual TSG_Intersection	On_Intersects		(TSG_Rect Extent)								= 0;
 
 	virtual void				_Invalidate			(void);
 
@@ -186,10 +213,12 @@ public:
 
 	virtual int					Get_Part_Count		(void)												{	return( 1 );				}
 	virtual int					Get_Point_Count		(int iPart)											{	return( 1 );				}
-	virtual TSG_Point			Get_Point			(int iPoint, int iPart = 0)							{	return( m_Point );			}
+	virtual TSG_Point			Get_Point			(int iPoint, int iPart = 0, bool bAscending = true)	{	return( m_Point );			}
 
 	virtual const CSG_Rect &	Get_Extent			(void);
 
+	virtual TSG_Point			Get_Centroid		(void)												{	return( m_Point );			}
+
 	virtual double				Get_Distance		(TSG_Point Point)									{	return( SG_Get_Distance(Point, m_Point) );	}
 	virtual double				Get_Distance		(TSG_Point Point, int iPart)						{	return( SG_Get_Distance(Point, m_Point) );	}
 	virtual double				Get_Distance		(TSG_Point Point, TSG_Point &Next)					{	Next = m_Point; return( SG_Get_Distance(Point, m_Point) );	}
@@ -206,7 +235,50 @@ protected:
 
 
 	virtual bool				On_Assign			(CSG_Shape *pShape);
-	virtual int					On_Intersects		(TSG_Rect Region);
+	virtual TSG_Intersection	On_Intersects		(CSG_Shape *pShape);
+	virtual TSG_Intersection	On_Intersects		(TSG_Rect Region);
+
+};
+
+//---------------------------------------------------------
+class SAGA_API_DLL_EXPORT CSG_Shape_Point_Z : public CSG_Shape_Point
+{
+	friend class CSG_Shapes;
+
+public:
+
+	CSG_Shape_Point_Z(class CSG_Shapes *pOwner, int Index) : CSG_Shape_Point(pOwner, Index)				{	m_Z	= 0.0;	}
+
+	virtual void				Set_Z				(double z, int iPoint, int iPart = 0)				{	m_Z	= z;	_Invalidate();	}
+	virtual double				Get_Z				(int iPoint, int iPart = 0, bool bAscending = true)	{	return( m_Z );	}
+	virtual double				Get_ZMin			(void)												{	return( m_Z );	}
+	virtual double				Get_ZMax			(void)												{	return( m_Z );	}
+
+
+private:
+
+	double						m_Z;
+
+};
+
+//---------------------------------------------------------
+class SAGA_API_DLL_EXPORT CSG_Shape_Point_ZM : public CSG_Shape_Point_Z
+{
+	friend class CSG_Shapes;
+
+public:
+
+	CSG_Shape_Point_ZM(class CSG_Shapes *pOwner, int Index) : CSG_Shape_Point_Z(pOwner, Index)			{	m_M	= 0.0;	}
+
+	virtual void				Set_M				(double m, int iPoint, int iPart = 0)				{	m_M	= m;	_Invalidate();	}
+	virtual double				Get_M				(int iPoint, int iPart = 0, bool bAscending = true)	{	return( m_M );	}
+	virtual double				Get_MMin			(void)												{	return( m_M );	}
+	virtual double				Get_MMax			(void)												{	return( m_M );	}
+
+
+private:
+
+	double						m_M;
 
 };
 
@@ -226,33 +298,46 @@ class SAGA_API_DLL_EXPORT CSG_Shape_Part
 
 public:
 
-	bool						Destroy				(void);
+	class CSG_Shape_Points *	Get_Owner			(void)	{	return( m_pOwner );	}
 
-	bool						Assign				(CSG_Shape_Part *pPart);
+	virtual bool				Destroy				(void);
+	virtual bool				Assign				(CSG_Shape_Part *pPart);
 
 	const CSG_Rect &			Get_Extent			(void)	{	_Update_Extent();	return( m_Extent );	}
 
 	int							Get_Count			(void)	{	return( m_nPoints );	}
 
-	TSG_Point					Get_Point			(int iPoint)
+	TSG_Point					Get_Point			(int iPoint, bool bAscending = true)
 	{
 		if( iPoint >= 0 && iPoint < m_nPoints )
 		{
-			return( m_Points[iPoint] );
+			return( m_Points[bAscending ? iPoint : m_nPoints - 1 - iPoint] );
 		}
 
 		return( CSG_Point(0.0, 0.0) );
 	}
 
-	int							Add_Point			(TSG_Point Point               )	{	return( Add_Point(Point.x, Point.y)         );	}
-	int							Ins_Point			(TSG_Point Point,    int iPoint)	{	return( Ins_Point(Point.x, Point.y, iPoint) );	}
-	int							Set_Point			(TSG_Point Point,    int iPoint)	{	return( Set_Point(Point.x, Point.y, iPoint) );	}
+	int							Add_Point			(TSG_Point Point               )		{	return( Add_Point(Point.x, Point.y)         );	}
+	int							Ins_Point			(TSG_Point Point,    int iPoint)		{	return( Ins_Point(Point.x, Point.y, iPoint) );	}
+	int							Set_Point			(TSG_Point Point,    int iPoint)		{	return( Set_Point(Point.x, Point.y, iPoint) );	}
 
 	int							Add_Point			(double x, double y            );
 	int							Ins_Point			(double x, double y, int iPoint);
 	int							Set_Point			(double x, double y, int iPoint);
 	int							Del_Point			(                    int iPoint);
 
+	void						Set_Z				(double z, int iPoint)					{	if    ( m_Z && iPoint >= 0 && iPoint < m_nPoints ) { m_Z[iPoint] = z; _Invalidate(); }	}
+	double						Get_Z				(int iPoint, bool bAscending = true)	{	return( m_Z && iPoint >= 0 && iPoint < m_nPoints ?   m_Z[bAscending ? iPoint : m_nPoints - 1 - iPoint] : 0.0 );	}
+	double						Get_ZMin			(void)									{	_Update_Extent(); return( m_ZMin );	}
+	double						Get_ZMax			(void)									{	_Update_Extent(); return( m_ZMax );	}
+
+	void						Set_M				(double m, int iPoint)					{	if    ( m_M && iPoint >= 0 && iPoint < m_nPoints ) { m_M[iPoint] = m; _Invalidate(); }	}
+	double						Get_M				(int iPoint, bool bAscending = true)	{	return( m_M && iPoint >= 0 && iPoint < m_nPoints ?	 m_M[bAscending ? iPoint : m_nPoints - 1 - iPoint] : 0.0 );	}
+	double						Get_MMin			(void)									{	_Update_Extent(); return( m_MMin );	}
+	double						Get_MMax			(void)									{	_Update_Extent(); return( m_MMax );	}
+
+	bool						Revert_Points		(void);
+
 
 protected:
 
@@ -264,17 +349,17 @@ protected:
 
 	int							m_nPoints, m_nBuffer;
 
+	double						*m_Z, m_ZMin, m_ZMax, *m_M, m_MMin, m_MMax;
+
 	TSG_Point					*m_Points;
 
 	CSG_Rect					m_Extent;
 
-	CSG_Shape_Points			*m_pOwner;
+	class CSG_Shape_Points		*m_pOwner;
 
 
-	bool						_Alloc_Memory		(int nPoints);
-
+	virtual bool				_Alloc_Memory		(int nPoints);
 	virtual void				_Invalidate			(void);
-
 	virtual void				_Update_Extent		(void);
 
 };
@@ -303,6 +388,10 @@ public:
 	virtual int					Set_Point			(double x, double y, int iPoint, int iPart = 0);
 	virtual int					Del_Point			(                    int iPoint, int iPart = 0);
 
+	int							Add_Point			(const TSG_Point &p,             int iPart = 0)	{	return( Add_Point(p.x, p.y        , iPart) );	}
+	int							Ins_Point			(const TSG_Point &p, int iPoint, int iPart = 0)	{	return( Ins_Point(p.x, p.y, iPoint, iPart) );	}
+	int							Set_Point			(const TSG_Point &p, int iPoint, int iPart = 0)	{	return( Set_Point(p.x, p.y, iPoint, iPart) );	}
+
 	virtual int					Del_Part			(int iPart);
 	virtual int					Del_Parts			(void);
 
@@ -310,23 +399,37 @@ public:
 	virtual CSG_Shape_Part *	Get_Part			(int iPart)	{	return( iPart >= 0 && iPart < m_nParts ? m_pParts[iPart] : NULL );	}
 	virtual int					Get_Point_Count		(int iPart)	{	return( iPart >= 0 && iPart < m_nParts ? m_pParts[iPart]->Get_Count() : 0 );	}
 
-	virtual TSG_Point			Get_Point			(int iPoint, int iPart = 0)
+	virtual TSG_Point			Get_Point			(int iPoint, int iPart = 0, bool bAscending = true)
 	{
-		if( iPart >= 0 && iPart < m_nParts && iPoint >= 0 && iPoint < m_pParts[iPart]->Get_Count() )
+		if( iPart >= 0 && iPart < m_nParts )
 		{
-			return( m_pParts[iPart]->Get_Point(iPoint) );
+			return( m_pParts[iPart]->Get_Point(iPoint, bAscending) );
 		}
 
 		return( CSG_Point(0.0, 0.0) );
 	}
 
+	virtual void				Set_Z				(double z, int iPoint, int iPart = 0)							{	if    ( iPart >= 0 && iPart < m_nParts ) m_pParts[iPart]->Set_Z(z, iPoint);	}
+	virtual double				Get_Z				(          int iPoint, int iPart = 0, bool bAscending = true)	{	return( iPart >= 0 && iPart < m_nParts ? m_pParts[iPart]->Get_Z(   iPoint, bAscending) : 0.0 );	}
+	virtual double				Get_ZMin			(void)		{	_Update_Extent();	return( m_ZMin );	}
+	virtual double				Get_ZMax			(void)		{	_Update_Extent();	return( m_ZMax );	}
+
+	virtual void				Set_M				(double m, int iPoint, int iPart = 0)							{	if    ( iPart >= 0 && iPart < m_nParts ) m_pParts[iPart]->Set_M(m, iPoint);	}
+	virtual double				Get_M				(          int iPoint, int iPart = 0, bool bAscending = true)	{	return( iPart >= 0 && iPart < m_nParts ? m_pParts[iPart]->Get_M(   iPoint, bAscending) : 0.0 );	}
+	virtual double				Get_MMin			(void)		{	_Update_Extent();	return( m_MMin );	}
+	virtual double				Get_MMax			(void)		{	_Update_Extent();	return( m_MMax );	}
+
 	virtual const CSG_Rect &	Get_Extent			(void)		{	_Update_Extent();	return( m_Extent );	}
 
+	virtual TSG_Point			Get_Centroid		(void);
+
 	virtual double				Get_Distance		(TSG_Point Point);
 	virtual double				Get_Distance		(TSG_Point Point, int iPart);
 	virtual double				Get_Distance		(TSG_Point Point, TSG_Point &Next);
 	virtual double				Get_Distance		(TSG_Point Point, TSG_Point &Next, int iPart);
 
+	virtual bool				Revert_Points		(int iPart)	{	return( iPart >= 0 && iPart < m_nParts ? m_pParts[iPart]->Revert_Points() : false );	}
+
 
 protected:
 
@@ -338,6 +441,8 @@ protected:
 
 	int							m_nParts;
 
+	double						m_ZMin, m_ZMax, m_MMin, m_MMax;
+
 	CSG_Rect					m_Extent;
 
 	CSG_Shape_Part				**m_pParts;
@@ -360,8 +465,8 @@ protected:
 	void						_Update_Extent		(void);
 
 	virtual bool				On_Assign			(CSG_Shape *pShape);
-
-	virtual int					On_Intersects		(TSG_Rect Region);
+	virtual TSG_Intersection	On_Intersects		(CSG_Shape *pShape);
+	virtual TSG_Intersection	On_Intersects		(TSG_Rect Region);
 
 };
 
@@ -381,6 +486,8 @@ public:
 
 	virtual bool				is_Valid			(void)	{	return( m_nParts > 0 && m_pParts[0]->Get_Count() > 1 );	}
 
+	virtual TSG_Point			Get_Centroid		(void);
+
 	double						Get_Length			(void);
 	double						Get_Length			(int iPart);
 
@@ -392,7 +499,8 @@ protected:
 	CSG_Shape_Line(class CSG_Shapes *pOwner, int Index);
 	virtual ~CSG_Shape_Line(void);
 
-	virtual int					On_Intersects		(TSG_Rect Region);
+	virtual TSG_Intersection	On_Intersects		(CSG_Shape *pShape);
+	virtual TSG_Intersection	On_Intersects		(TSG_Rect Region);
 
 };
 
@@ -418,8 +526,8 @@ public:
 
 	const TSG_Point &			Get_Centroid		(void)	{	_Update_Area();	return( m_Centroid );	}
 
-	bool						is_Containing		(const TSG_Point &Point);
-	bool						is_Containing		(double x, double y);
+	bool						Contains			(const TSG_Point &Point);
+	bool						Contains			(double x, double y);
 
 	double						Get_Distance		(TSG_Point Point, TSG_Point &Next);
 
@@ -468,10 +576,10 @@ public:
 	TSG_Point					Get_Centroid		(int iPart);
 	TSG_Point					Get_Centroid		(void);
 
-	bool						is_Containing		(const TSG_Point &Point, int iPart);
-	bool						is_Containing		(const TSG_Point &Point);
-	bool						is_Containing		(double x, double y, int iPart);
-	bool						is_Containing		(double x, double y);
+	bool						Contains			(const TSG_Point &Point, int iPart);
+	bool						Contains			(const TSG_Point &Point);
+	bool						Contains			(double x, double y, int iPart);
+	bool						Contains			(double x, double y);
 
 	virtual double				Get_Distance		(TSG_Point Point, TSG_Point &Next, int iPart);
 
@@ -489,7 +597,8 @@ protected:
 
 	virtual void				_Invalidate			(void);
 
-	virtual int					On_Intersects		(TSG_Rect Region);
+	virtual TSG_Intersection	On_Intersects		(CSG_Shape *pShape);
+	virtual TSG_Intersection	On_Intersects		(TSG_Rect Region);
 
 };
 
@@ -525,8 +634,8 @@ public:
 									CSG_Shapes	(const CSG_String &File_Name);
 	bool							Create		(const CSG_String &File_Name);
 
-									CSG_Shapes	(TSG_Shape_Type Type, const SG_Char *Name = NULL, CSG_Table *pStructure = NULL);
-	bool							Create		(TSG_Shape_Type Type, const SG_Char *Name = NULL, CSG_Table *pStructure = NULL);
+									CSG_Shapes	(TSG_Shape_Type Type, const SG_Char *Name = NULL, CSG_Table *pStructure = NULL, TSG_Vertex_Type Vertex_Type = SG_VERTEX_TYPE_XY);
+	bool							Create		(TSG_Shape_Type Type, const SG_Char *Name = NULL, CSG_Table *pStructure = NULL, TSG_Vertex_Type Vertex_Type = SG_VERTEX_TYPE_XY);
 
 	virtual ~CSG_Shapes(void);
 
@@ -540,41 +649,59 @@ public:
 
 	virtual bool					is_Valid				(void)	const			{	return( m_Type != SHAPE_TYPE_Undefined && Get_Count() >= 0 );		}
 
-	TSG_Shape_Type					Get_Type				(void)	const			{	return( m_Type );		}
+	virtual TSG_Shape_Type			Get_Type				(void)	const			{	return( m_Type );		}
+
+	TSG_Vertex_Type					Get_Vertex_Type			(void)	const			{	return( m_Vertex_Type );	}
 
 	const CSG_Rect &				Get_Extent				(void)					{	Update();	return( m_Extent );	}
 
-	//-----------------------------------------------------
-	CSG_Shape *						Add_Shape				(CSG_Table_Record *pCopy = NULL, TSG_ADD_Shape_Copy_Mode mCopy = SHAPE_COPY);
-	bool							Del_Shape				(int iShape);
-	bool							Del_Shape				(CSG_Shape *pShape);
-	bool							Del_Shapes				(void)					{	return( Del_Records() );	}
+	double							Get_ZMin				(void)					{	Update();	return( m_ZMin );	}
+	double							Get_ZMax				(void)					{	Update();	return( m_ZMax );	}
+	double							Get_MMin				(void)					{	Update();	return( m_MMin );	}
+	double							Get_MMax				(void)					{	Update();	return( m_MMax );	}
 
-	CSG_Shape *						Get_Shape				(TSG_Point Point, double Epsilon = 0.0);
-	CSG_Shape *						Get_Shape				(int iShape)	const	{	return( (CSG_Shape *)Get_Record(iShape) );	}
-	CSG_Shape *						Get_Shape_byIndex		(int Index)		const	{	return( (CSG_Shape *)Get_Record_byIndex(Index) );	}
+	//-----------------------------------------------------
+	virtual CSG_Shape *				Add_Shape				(CSG_Table_Record *pCopy = NULL, TSG_ADD_Shape_Copy_Mode mCopy = SHAPE_COPY);
+	virtual bool					Del_Shape				(int iShape);
+	virtual bool					Del_Shape				(CSG_Shape *pShape);
+	virtual bool					Del_Shapes				(void)					{	return( Del_Records() );	}
+
+	virtual CSG_Shape *				Get_Shape				(TSG_Point Point, double Epsilon = 0.0);
+	virtual CSG_Shape *				Get_Shape				(int iShape)	const	{	return( (CSG_Shape *)Get_Record(iShape) );	}
+	virtual CSG_Shape *				Get_Shape_byIndex		(int Index)		const	{	return( (CSG_Shape *)Get_Record_byIndex(Index) );	}
+
+	//-----------------------------------------------------
+	bool							Make_Clean				(void);
 
 	//-----------------------------------------------------
 	virtual CSG_Shape *				Get_Selection			(int Index = 0)			{	return( (CSG_Shape *)CSG_Table::Get_Selection(Index) );	};
-	const CSG_Rect &				Get_Selection_Extent	(void);
+	virtual const CSG_Rect &		Get_Selection_Extent	(void);
 
-	virtual bool					Select					(CSG_Shape *pShape = NULL, bool bInvert = false);
-	virtual bool					Select					(TSG_Rect Extent         , bool bInvert = false);
-	virtual bool					Select					(TSG_Point Point         , bool bInvert = false);
+	virtual bool					Select					(int Index					, bool bInvert = false);
+	virtual bool					Select					(CSG_Shape *pShape = NULL	, bool bInvert = false);
+	virtual bool					Select					(TSG_Rect Extent			, bool bInvert = false);
+	virtual bool					Select					(TSG_Point Point			, bool bInvert = false);
 
 
 protected:
 
+	double							m_ZMin, m_ZMax, m_MMin, m_MMax;
+
 	TSG_Shape_Type					m_Type;
 
+	TSG_Vertex_Type					m_Vertex_Type;
+
 	CSG_Rect						m_Extent, m_Extent_Selected;
 
 
+	virtual bool					On_Update				(void);
+
 	virtual void					_On_Construction		(void);
 
 	virtual CSG_Table_Record *		_Get_New_Record			(int Index);
 
-	virtual bool					On_Update				(void);
+
+private:
 
 	bool							_Load_ESRI				(const CSG_String &File_Name);
 	bool							_Save_ESRI				(const CSG_String &File_Name);
@@ -599,7 +726,10 @@ SAGA_API_DLL_EXPORT CSG_Shapes *	SG_Create_Shapes	(const CSG_Shapes &Shapes);
 SAGA_API_DLL_EXPORT CSG_Shapes *	SG_Create_Shapes	(const CSG_String &File_Name);
 
 /** Safe shapes construction */
-SAGA_API_DLL_EXPORT CSG_Shapes *	SG_Create_Shapes	(TSG_Shape_Type Type, const SG_Char *Name = NULL, CSG_Table *pStructure = NULL);
+SAGA_API_DLL_EXPORT CSG_Shapes *	SG_Create_Shapes	(TSG_Shape_Type Type, const SG_Char *Name = NULL, CSG_Table *pStructure = NULL, TSG_Vertex_Type Vertex_Type = SG_VERTEX_TYPE_XY);
+
+/** Safe shapes construction */
+SAGA_API_DLL_EXPORT CSG_Shapes *	SG_Create_Shapes	(CSG_Shapes *pTemplate);
 
 
 ///////////////////////////////////////////////////////////
@@ -615,6 +745,7 @@ public:
 
 	virtual bool			is_Leaf			(void)	const	{	return( false );	}
 	virtual bool			is_Node			(void)	const	{	return( false );	}
+	virtual bool			has_Statistics	(void)	const	{	return( false );	}
 
 	CSG_Rect				Get_Extent		(void)	const	{	return( CSG_Rect(m_xCenter - m_Size, m_yCenter - m_Size, m_xCenter + m_Size, m_yCenter + m_Size) );	}
 	double					Get_xMin		(void)	const	{	return( m_xCenter - m_Size );	}
@@ -681,6 +812,47 @@ protected:
 
 };
 
+//---------------------------------------------------------
+class SAGA_API_DLL_EXPORT CSG_PRQuadTree_Leaf_List : public CSG_PRQuadTree_Leaf
+{
+	friend class CSG_PRQuadTree_Node;
+
+public:
+
+	virtual bool			has_Statistics	(void)	const	{	return( true );	}
+
+	int						Get_Count		(void)	{	return( s_z.Get_Count   () );	}
+	double					Get_Value		(int i)	{	return( s_z.Get_Value  (i) );	}
+	double					Get_Minimum		(void)	{	return( s_z.Get_Minimum () );	}
+	double					Get_Maximum		(void)	{	return( s_z.Get_Maximum () );	}
+	double					Get_Range		(void)	{	return( s_z.Get_Range   () );	}
+	double					Get_Sum			(void)	{	return( s_z.Get_Sum     () );	}
+	double					Get_Mean		(void)	{	return( s_z.Get_Mean    () );	}
+	double					Get_Variance	(void)	{	return( s_z.Get_Variance() );	}
+	double					Get_StdDev		(void)	{	return( s_z.Get_StdDev  () );	}
+
+
+protected:
+
+	CSG_PRQuadTree_Leaf_List(double xCenter, double yCenter, double Size, double x, double y, double z)
+		: CSG_PRQuadTree_Leaf(xCenter, yCenter, Size, x, y, z)
+	{
+		s_z.Create(true);
+
+		s_z.Add_Value(z);
+	}
+
+	void					Add_Value		(double z)
+	{
+		s_z.Add_Value(z);
+
+		m_z	= s_z.Get_Mean();
+	}
+
+	CSG_Simple_Statistics	s_z;
+
+};
+
 //---------------------------------------------------------
 class SAGA_API_DLL_EXPORT CSG_PRQuadTree_Node : public CSG_PRQuadTree_Item
 {
@@ -691,9 +863,14 @@ public:
 	virtual bool			is_Node			(void)	const	{	return( true );		}
 
 	CSG_PRQuadTree_Item *	Get_Child		(int i)	const	{	return( i >= 0 && i < 4 ? m_pChildren[i] : NULL );	}
+	CSG_PRQuadTree_Item *	Get_Child		(double x, double y);
 
 	bool					Add_Point		(double x, double y, double z);
 
+	virtual CSG_Simple_Statistics *	Get_X	(void)			{	return( NULL );	}
+	virtual CSG_Simple_Statistics *	Get_Y	(void)			{	return( NULL );	}
+	virtual CSG_Simple_Statistics *	Get_Z	(void)			{	return( NULL );	}
+
 
 protected:
 
@@ -706,38 +883,80 @@ protected:
 
 };
 
+//---------------------------------------------------------
+class SAGA_API_DLL_EXPORT CSG_PRQuadTree_Node_Statistics : public CSG_PRQuadTree_Node
+{
+	friend class CSG_PRQuadTree;
+	friend class CSG_PRQuadTree_Node;
+
+public:
+
+	virtual bool			has_Statistics	(void)	const	{	return( true );	}
+
+	virtual CSG_Simple_Statistics *	Get_X	(void)			{	return( &m_x );	}
+	virtual CSG_Simple_Statistics *	Get_Y	(void)			{	return( &m_y );	}
+	virtual CSG_Simple_Statistics *	Get_Z	(void)			{	return( &m_z );	}
+
+
+protected:
+
+	CSG_PRQuadTree_Node_Statistics(double xCenter, double yCenter, double Size)
+		: CSG_PRQuadTree_Node(xCenter, yCenter, Size)
+	{}
+
+	CSG_PRQuadTree_Node_Statistics(CSG_PRQuadTree_Leaf *pLeaf)
+		: CSG_PRQuadTree_Node(pLeaf)
+	{}
+
+
+	CSG_Simple_Statistics	m_x, m_y, m_z;
+
+};
+
 //---------------------------------------------------------
 class SAGA_API_DLL_EXPORT CSG_PRQuadTree
 {
 public:
 	CSG_PRQuadTree(void);
-	CSG_PRQuadTree(const TSG_Rect &Extent);
-	CSG_PRQuadTree(CSG_Shapes *pShapes, int Attribute);
+	CSG_PRQuadTree(const TSG_Rect &Extent, bool bStatistics = false);
+	CSG_PRQuadTree(CSG_Shapes *pShapes, int Attribute, bool bStatistics = false);
 	virtual ~CSG_PRQuadTree(void);
 
-	bool						Create					(const CSG_Rect &Extent);
-	bool						Create					(CSG_Shapes *pShapes, int Attribute);
+	bool						Create					(const CSG_Rect &Extent, bool bStatistics = false);
+	bool						Create					(CSG_Shapes *pShapes, int Attribute, bool bStatistics = false);
 	void						Destroy					(void);
 
 	bool						Add_Point				(double x, double y, double z);
+	bool						Add_Point				(const TSG_Point &p, double z);
 
-	const CSG_PRQuadTree_Node &	Get_Root				(void) const	{	return( *m_pRoot );			}
+	int							Get_Point_Count			(void)	const	{	return( m_nPoints );		}
 
-	bool						is_Okay					(void) const	{	return( m_pRoot != NULL );	}
+	const CSG_PRQuadTree_Node &	Get_Root				(void)	const	{	return( *m_pRoot );			}
+	CSG_PRQuadTree_Node *		Get_Root_Pointer		(void)	const	{	return(  m_pRoot );			}
 
+	bool						is_Okay					(void)	const	{	return( m_pRoot != NULL );	}
+
+	CSG_PRQuadTree_Leaf *		Get_Nearest_Leaf		(const TSG_Point &p, double &Distance);
+	CSG_PRQuadTree_Leaf *		Get_Nearest_Leaf		(double x, double y, double &Distance);
+	bool						Get_Nearest_Point		(const TSG_Point &p, TSG_Point &Point, double &Value, double &Distance);
 	bool						Get_Nearest_Point		(double x, double y, TSG_Point &Point, double &Value, double &Distance);
 
+	int							Select_Nearest_Points	(const TSG_Point &p, int maxPoints, double Radius = 0.0, int iQuadrant = -1);
 	int							Select_Nearest_Points	(double x, double y, int maxPoints, double Radius = 0.0, int iQuadrant = -1);
 
-	int							Get_Selected_Count		(void) const	{	return( m_nSelected );		}
-
+	int							Get_Selected_Count		(void)	const	{	return( (int)m_Selected.Get_Size() );	}
+	CSG_PRQuadTree_Leaf *		Get_Selected_Leaf		(int i) const	{	TLeaf *pLeaf = _Get_Selected(i); return( pLeaf ? pLeaf->pLeaf          : NULL );	}
+	double						Get_Selected_Z			(int i) const	{	TLeaf *pLeaf = _Get_Selected(i); return( pLeaf ? pLeaf->pLeaf->Get_Z() :  0.0 );	}
+	double						Get_Selected_Distance	(int i) const	{	TLeaf *pLeaf = _Get_Selected(i); return( pLeaf ? pLeaf->Distance       : -1.0 );	}
 	bool						Get_Selected_Point		(int i, double &x, double &y, double &z) const
 	{
-		if( i >= 0 && i < m_nSelected )
+		CSG_PRQuadTree_Leaf	*pLeaf	= Get_Selected_Leaf(i);
+
+		if( pLeaf )
 		{
-			x	= m_Selected[i][0];
-			y	= m_Selected[i][1];
-			z	= m_Selected[i][2];
+			x	= pLeaf->Get_X();
+			y	= pLeaf->Get_Y();
+			z	= pLeaf->Get_Z();
 
 			return( true );
 		}
@@ -748,12 +967,29 @@ public:
 
 private:
 
-	int							m_nSelected, m_nPoints;
+	typedef struct SLeaf
+	{
+		CSG_PRQuadTree_Leaf		*pLeaf;
 
-	CSG_Matrix					m_Selected;
+		double					Distance;
+	}
+	TLeaf;
+
+
+private:
+
+	int							m_nPoints;
+
+	CSG_Array					m_Selected;
 
 	CSG_PRQuadTree_Node			*m_pRoot;
 
+	bool						_Check_Root				(double x, double y);
+
+	TLeaf *						_Get_Selected			(int i)	const	{	return( i >= 0 && i < (int)m_Selected.Get_Size() ? ((TLeaf *)m_Selected.Get_Array()) + i : NULL );	}
+	bool						_Add_Selected			(CSG_PRQuadTree_Leaf *pLeaf, double Distance);
+	bool						_Set_Selected			(int i, CSG_PRQuadTree_Leaf *pLeaf, double Distance);
+
 	bool						_Quadrant_Contains		(double x, double y, int iQuadrant, const TSG_Point &p);
 	bool						_Radius_Contains		(double x, double y, double r, const TSG_Point &p);
 	bool						_Radius_Contains		(double x, double y, double r, int iQuadrant, const TSG_Point &p);
@@ -761,8 +997,8 @@ private:
 	bool						_Radius_Intersects		(double x, double y, double r, CSG_PRQuadTree_Item *pItem);
 	bool						_Radius_Intersects		(double x, double y, double r, int iQuadrant, CSG_PRQuadTree_Item *pItem);
 
-	void						_Get_Nearest_Point		(CSG_PRQuadTree_Item *pItem, double x, double y, double &maxDistance, double Point[4]);
-	void						_Get_Nearest_Points		(CSG_PRQuadTree_Item *pItem, double x, double y, double &maxDistance, double Radius, int iQuadrant);
+	CSG_PRQuadTree_Leaf	*		_Get_Nearest_Point		(CSG_PRQuadTree_Item *pItem, double x, double y, double &Distance);
+	void						_Get_Nearest_Points		(CSG_PRQuadTree_Item *pItem, double x, double y, double &Distance, double Radius, int maxPoints, int iQuadrant);
 
 };
 
@@ -834,6 +1070,171 @@ protected:
 };
 
 
+///////////////////////////////////////////////////////////
+//														 //
+//					Polygon Tools						 //
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+SAGA_API_DLL_EXPORT bool		SG_Polygon_Intersection	(CSG_Shape *pPolygon, CSG_Shape *pClip, CSG_Shape *pResult = NULL);
+SAGA_API_DLL_EXPORT bool		SG_Polygon_Difference	(CSG_Shape *pPolygon, CSG_Shape *pClip, CSG_Shape *pResult = NULL);
+SAGA_API_DLL_EXPORT bool		SG_Polygon_ExclusiveOr	(CSG_Shape *pPolygon, CSG_Shape *pClip, CSG_Shape *pResult = NULL);
+SAGA_API_DLL_EXPORT bool		SG_Polygon_Union		(CSG_Shape *pPolygon, CSG_Shape *pClip, CSG_Shape *pResult = NULL);
+SAGA_API_DLL_EXPORT bool		SG_Polygon_Dissolve		(CSG_Shape *pPolygon, CSG_Shape *pResult = NULL);
+
+
+///////////////////////////////////////////////////////////
+//														 //
+//						OpenGIS							 //
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+enum ESG_OGIS_ByteOrder
+{
+	SG_OGIS_BYTEORDER_XDR				= 0,	// Big Endian
+	SG_OGIS_BYTEORDER_NDR				= 1		// Little Endian
+};
+
+//---------------------------------------------------------
+enum ESG_SG_OGIS_Type_Geometry
+{
+	SG_OGIS_TYPE_Point					=    1,
+	SG_OGIS_TYPE_LineString				=    2,
+	SG_OGIS_TYPE_Polygon				=    3,
+	SG_OGIS_TYPE_MultiPoint				=    4,
+	SG_OGIS_TYPE_MultiLineString		=    5,
+	SG_OGIS_TYPE_MultiPolygon			=    6,
+	SG_OGIS_TYPE_GeometryCollection		=    7,
+	SG_OGIS_TYPE_PolyhedralSurface		=   15,
+	SG_OGIS_TYPE_TIN					=   16,
+	SG_OGIS_TYPE_Triangle				=   17,
+
+	SG_OGIS_TYPE_PointZ					= 1001,
+	SG_OGIS_TYPE_LineStringZ			= 1002,
+	SG_OGIS_TYPE_PolygonZ				= 1003,
+	SG_OGIS_TYPE_MultiPointZ			= 1004,
+	SG_OGIS_TYPE_MultiLineStringZ		= 1005,
+	SG_OGIS_TYPE_MultiPolygonZ			= 1006,
+	SG_OGIS_TYPE_GeometryCollectionZ	= 1007,
+	SG_OGIS_TYPE_PolyhedralSurfaceZ		= 1015,
+	SG_OGIS_TYPE_TINZ					= 1016,
+	SG_OGIS_TYPE_Trianglez				= 1017,
+
+	SG_OGIS_TYPE_PointM					= 2001,
+	SG_OGIS_TYPE_LineStringM			= 2002,
+	SG_OGIS_TYPE_PolygonM				= 2003,
+	SG_OGIS_TYPE_MultiPointM			= 2004,
+	SG_OGIS_TYPE_MultiLineStringM		= 2005,
+	SG_OGIS_TYPE_MultiPolygonM			= 2006,
+	SG_OGIS_TYPE_GeometryCollectionM	= 2007,
+	SG_OGIS_TYPE_PolyhedralSurfaceM		= 2015,
+	SG_OGIS_TYPE_TINM					= 2016,
+	SG_OGIS_TYPE_TriangleM				= 2017,
+
+	SG_OGIS_TYPE_PointZM				= 3001,
+	SG_OGIS_TYPE_LineStringZM			= 3002,
+	SG_OGIS_TYPE_PolygonZM				= 3003,
+	SG_OGIS_TYPE_MultiPointZM			= 3004,
+	SG_OGIS_TYPE_MultiLineStringZM		= 3005,
+	SG_OGIS_TYPE_MultiPolygonZM			= 3006,
+	SG_OGIS_TYPE_GeometryCollectionZM	= 3007,
+	SG_OGIS_TYPE_PolyhedralSurfaceZM	= 3015,
+	SG_OGIS_TYPE_TinZM					= 3016,
+	SG_OGIS_TYPE_TriangleZM				= 3017
+};
+
+//---------------------------------------------------------
+#define SG_OGIS_TYPE_STR_Point					SG_T("Point")
+#define SG_OGIS_TYPE_STR_Line					SG_T("LineString")
+#define SG_OGIS_TYPE_STR_Polygon				SG_T("Polygon")
+#define SG_OGIS_TYPE_STR_MultiPoint			SG_T("MultiPoint")
+#define SG_OGIS_TYPE_STR_MultiLine				SG_T("MultiLineString")
+#define SG_OGIS_TYPE_STR_MultiPolygon			SG_T("MultiPolygon")
+#define SG_OGIS_TYPE_STR_GeometryCollection	SG_T("GeometryCollection")
+#define SG_OGIS_TYPE_STR_PolyhedralSurface		SG_T("PolyhedralSurface")
+#define SG_OGIS_TYPE_STR_TIN					SG_T("TIN")
+#define SG_OGIS_TYPE_STR_Triangle				SG_T("Triangle")
+
+#define SG_OGIS_TYPE_STR_Point_Z				SG_T("Point Z")
+#define SG_OGIS_TYPE_STR_Line_Z				SG_T("LineString Z")
+#define SG_OGIS_TYPE_STR_Polygon_Z				SG_T("Polygon Z")
+#define SG_OGIS_TYPE_STR_MultiPoint_Z			SG_T("MultiPoint Z")
+#define SG_OGIS_TYPE_STR_MultiLine_Z			SG_T("MultiLineString Z")
+#define SG_OGIS_TYPE_STR_MultiPolygon_Z		SG_T("MultiPolygon Z")
+#define SG_OGIS_TYPE_STR_GeometryCollection_Z	SG_T("GeometryCollection Z")
+#define SG_OGIS_TYPE_STR_PolyhedralSurface_Z	SG_T("PolyhedralSurface Z")
+#define SG_OGIS_TYPE_STR_TIN_Z					SG_T("TIN Z")
+#define SG_OGIS_TYPE_STR_Triangle_Z			SG_T("Triangle Z")
+
+#define SG_OGIS_TYPE_STR_Point_M				SG_T("Point M")
+#define SG_OGIS_TYPE_STR_Line_M				SG_T("LineString M")
+#define SG_OGIS_TYPE_STR_Polygon_M				SG_T("Polygon M")
+#define SG_OGIS_TYPE_STR_MultiPoint_M			SG_T("MultiPoint M")
+#define SG_OGIS_TYPE_STR_MultiLine_M			SG_T("MultiLineString M")
+#define SG_OGIS_TYPE_STR_MultiPolygon_M		SG_T("MultiPolygon M")
+#define SG_OGIS_TYPE_STR_GeometryCollection_M	SG_T("GeometryCollection M")
+#define SG_OGIS_TYPE_STR_PolyhedralSurface_M	SG_T("PolyhedralSurface M")
+#define SG_OGIS_TYPE_STR_TIN_M					SG_T("TIN M")
+#define SG_OGIS_TYPE_STR_Triangle_M			SG_T("Triangle M")
+
+#define SG_OGIS_TYPE_STR_Point_ZM				SG_T("Point ZM")
+#define SG_OGIS_TYPE_STR_Line_ZM				SG_T("LineString ZM")
+#define SG_OGIS_TYPE_STR_Polygon_ZM			SG_T("Polygon ZM")
+#define SG_OGIS_TYPE_STR_MultiPoint_ZM			SG_T("MultiPoint ZM")
+#define SG_OGIS_TYPE_STR_MultiLine_ZM			SG_T("MultiLineString ZM")
+#define SG_OGIS_TYPE_STR_MultiPolygon_ZM		SG_T("MultiPolygon ZM")
+#define SG_OGIS_TYPE_STR_GeometryCollection_ZM	SG_T("GeometryCollection ZM")
+#define SG_OGIS_TYPE_STR_PolyhedralSurface_ZM	SG_T("PolyhedralSurface ZM")
+#define SG_OGIS_TYPE_STR_TIN_ZM				SG_T("TIN ZM")
+#define SG_OGIS_TYPE_STR_Triangle_ZM			SG_T("Triangle ZM")
+
+
+///////////////////////////////////////////////////////////
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+class SAGA_API_DLL_EXPORT CSG_Shapes_OGIS_Converter
+{
+public:
+	CSG_Shapes_OGIS_Converter(void)	{}
+
+	static bool				from_WKText				(const CSG_String &Text, CSG_Shape *pShape);
+	static bool				to_WKText				(CSG_Shape *pShape, CSG_String &Text);
+
+	static bool				from_WKBinary			(CSG_Bytes &Bytes, CSG_Shape *pShape);
+	static bool				to_WKBinary				(CSG_Shape *pShape, CSG_Bytes &Bytes);
+
+
+private:
+
+	static bool				_WKT_Read_Point			(const CSG_String &Text, CSG_Shape *pShape, int iPart);
+	static bool				_WKT_Read_Points		(const CSG_String &Text, CSG_Shape *pShape);
+	static bool				_WKT_Read_Parts			(const CSG_String &Text, CSG_Shape *pShape);
+	static bool				_WKT_Read_Polygon		(const CSG_String &Text, CSG_Shape *pShape);
+
+	static bool				_WKT_Write_Point		(CSG_String &Text, CSG_Shape *pShape, int iPoint, int iPart);
+	static bool				_WKT_Write_Points		(CSG_String &Text, CSG_Shape *pShape, int iPart);
+	static bool				_WKT_Write_Parts		(CSG_String &Text, CSG_Shape *pShape);
+	static bool				_WKT_Write_Polygon		(CSG_String &Text, CSG_Shape *pShape);
+
+	static bool				_WKB_Read_Point			(CSG_Bytes &Bytes, bool bSwapBytes, CSG_Shape *pShape, int iPart);
+	static bool				_WKB_Read_Points		(CSG_Bytes &Bytes, bool bSwapBytes, CSG_Shape *pShape);
+	static bool				_WKB_Read_Parts			(CSG_Bytes &Bytes, bool bSwapBytes, CSG_Shape *pShape);
+	static bool				_WKB_Read_MultiLine		(CSG_Bytes &Bytes, bool bSwapBytes, CSG_Shape *pShape);
+	static bool				_WKB_Read_MultiPolygon	(CSG_Bytes &Bytes, bool bSwapBytes, CSG_Shape *pShape);
+
+	static bool				_WKB_Write_Point		(CSG_Bytes &Bytes, CSG_Shape *pShape, int iPoint, int iPart);
+	static bool				_WKB_Write_Points		(CSG_Bytes &Bytes, CSG_Shape *pShape, int iPart);
+	static bool				_WKB_Write_Parts		(CSG_Bytes &Bytes, CSG_Shape *pShape);
+	static bool				_WKB_Write_MultiLine	(CSG_Bytes &Bytes, CSG_Shape *pShape);
+	static bool				_WKB_Write_MultiPolygon	(CSG_Bytes &Bytes, CSG_Shape *pShape);
+
+};
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 //														 //
