@@ -1,3 +1,6 @@
+/**********************************************************
+ * Version $Id: table.cpp 1169 2011-09-21 16:56:01Z oconrad $
+ *********************************************************/
 
 ///////////////////////////////////////////////////////////
 //                                                       //
@@ -60,8 +63,6 @@
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-#include <string.h>
-
 #include "table.h"
 #include "shapes.h"
 
@@ -81,7 +82,18 @@ CSG_Table * SG_Create_Table(void)
 //---------------------------------------------------------
 CSG_Table * SG_Create_Table(const CSG_Table &Table)
 {
-	return( new CSG_Table(Table) );
+	switch( Table.Get_ObjectType() )
+	{
+	case DATAOBJECT_TYPE_Table:
+		return( new CSG_Table(Table) );
+
+	case DATAOBJECT_TYPE_Shapes:
+	case DATAOBJECT_TYPE_PointCloud:
+		return( SG_Create_Shapes(*((CSG_Shapes *)&Table)) );
+
+	default:
+		return( NULL );
+	}
 }
 
 //---------------------------------------------------------
@@ -91,9 +103,25 @@ CSG_Table * SG_Create_Table(const CSG_String &File_Name)
 }
 
 //---------------------------------------------------------
-CSG_Table * SG_Create_Table(CSG_Table *pStructure)
+CSG_Table * SG_Create_Table(CSG_Table *pTemplate)
 {
-	return( new CSG_Table(pStructure) );
+	if( pTemplate )
+	{
+		switch( pTemplate->Get_ObjectType() )
+		{
+		case DATAOBJECT_TYPE_Table:
+			return( new CSG_Table(pTemplate) );
+
+		case DATAOBJECT_TYPE_Shapes:
+		case DATAOBJECT_TYPE_PointCloud:
+			return( SG_Create_Shapes((CSG_Shapes *)pTemplate) );
+
+		default:
+			break;
+		}
+	}
+
+	return( new CSG_Table() );
 }
 
 
@@ -146,7 +174,7 @@ CSG_Table::CSG_Table(const CSG_String &File_Name, TSG_Table_File_Type Format)
 
 bool CSG_Table::Create(const CSG_String &File_Name, TSG_Table_File_Type Format)
 {
-	return( is_Private() ? false : _Create(File_Name, Format, SG_T("\t")) );
+	return( is_Private() ? false : _Create(File_Name, Format, NULL) );
 }
 
 //---------------------------------------------------------
@@ -165,32 +193,32 @@ bool CSG_Table::Create(const CSG_String &File_Name, TSG_Table_File_Type Format,
 
 bool CSG_Table::_Create(const CSG_String &File_Name, TSG_Table_File_Type Format, const SG_Char *Separator)
 {
-	return( _Load(File_Name, Format, !Separator || !Separator[0] ? SG_T("\t") : Separator) );
+	return( _Load(File_Name, Format, Separator) );
 }
 
 //---------------------------------------------------------
-CSG_Table::CSG_Table(CSG_Table *pStructure)
+CSG_Table::CSG_Table(CSG_Table *pTemplate)
 	: CSG_Data_Object()
 {
 	_On_Construction();
 
-	Create(pStructure);
+	Create(pTemplate);
 }
 
-bool CSG_Table::Create(CSG_Table *pStructure)
+bool CSG_Table::Create(CSG_Table *pTemplate)
 {
-	return( is_Private() ? false : _Create(pStructure) );
+	return( is_Private() ? false : _Create(pTemplate) );
 }
 
-bool CSG_Table::_Create(CSG_Table *pStructure)
+bool CSG_Table::_Create(CSG_Table *pTemplate)
 {
 	_Destroy();
 
-	if( pStructure && pStructure->Get_Field_Count() > 0 )
+	if( pTemplate && pTemplate->Get_Field_Count() > 0 )
 	{
-		for(int i=0; i<pStructure->Get_Field_Count(); i++)
+		for(int i=0; i<pTemplate->Get_Field_Count(); i++)
 		{
-			Add_Field(pStructure->Get_Field_Name(i), pStructure->Get_Field_Type(i));
+			Add_Field(pTemplate->Get_Field_Name(i), pTemplate->Get_Field_Type(i));
 		}
 
 		return( true );
@@ -295,7 +323,11 @@ bool CSG_Table::_Assign(CSG_Data_Object *pObject)
 	int			i;
 	CSG_Table	*pTable;
 
-	if( pObject && pObject->is_Valid() && pObject->Get_ObjectType() == Get_ObjectType() )
+	if( pObject && pObject->is_Valid()
+	&&	(	pObject->Get_ObjectType() == DATAOBJECT_TYPE_Table
+		||	pObject->Get_ObjectType() == DATAOBJECT_TYPE_Shapes
+		||	pObject->Get_ObjectType() == DATAOBJECT_TYPE_PointCloud
+		) )
 	{
 		_Destroy();
 
@@ -409,7 +441,7 @@ bool CSG_Table::is_Compatible(CSG_Table *pTable, bool bExactMatch) const
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-void CSG_Table::Add_Field(const SG_Char *Name, TSG_Data_Type Type, int add_Field)
+bool CSG_Table::Add_Field(const SG_Char *Name, TSG_Data_Type Type, int add_Field)
 {
 	int		iField, iRecord;
 
@@ -446,12 +478,14 @@ void CSG_Table::Add_Field(const SG_Char *Name, TSG_Data_Type Type, int add_Field
 	}
 
 	Set_Modified();
+
+	return( true );
 }
 
 //---------------------------------------------------------
 #ifdef _SAGA_UNICODE
-void CSG_Table::Add_Field(const char *Name, TSG_Data_Type Type, int iField)
-{	Add_Field(CSG_String(Name), Type, iField);	}
+bool CSG_Table::Add_Field(const char *Name, TSG_Data_Type Type, int iField)
+{	return( Add_Field(CSG_String(Name), Type, iField) );	}
 #endif
 
 //---------------------------------------------------------
@@ -509,6 +543,80 @@ bool CSG_Table::Set_Field_Name(int iField, const SG_Char *Name)
 	return( false );
 }
 
+//---------------------------------------------------------
+bool CSG_Table::Set_Field_Type(int iField, TSG_Data_Type Type)
+{
+	if( iField >= 0 && iField < m_nFields )
+	{
+		if( Type != Get_Field_Type(iField) )
+		{
+			m_Field_Type[iField]	= Type;
+
+			for(int i=0; i<m_nRecords; i++)
+			{
+				CSG_Table_Value	*pOld	= m_Records[i]->m_Values[iField];
+				CSG_Table_Value	*pNew	= CSG_Table_Record::_Create_Value(Type);
+
+				switch( Type )
+				{
+				default:
+				case SG_DATATYPE_String:
+				case SG_DATATYPE_Date:		pNew->Set_Value(pOld->asString());	break;
+
+				case SG_DATATYPE_Color:
+				case SG_DATATYPE_Byte:
+				case SG_DATATYPE_Char:
+				case SG_DATATYPE_Word:
+				case SG_DATATYPE_Short:
+				case SG_DATATYPE_DWord:
+				case SG_DATATYPE_Int:
+				case SG_DATATYPE_ULong:
+				case SG_DATATYPE_Long:		pNew->Set_Value(pOld->asInt   ());	break;
+
+				case SG_DATATYPE_Float:
+				case SG_DATATYPE_Double:	pNew->Set_Value(pOld->asDouble());	break;
+
+				case SG_DATATYPE_Binary:	pNew->Set_Value(pOld->asBinary());	break;
+				}
+
+				m_Records[i]->m_Values[iField]	= pNew;
+
+				delete(pOld);
+			}
+		}
+
+		return( true );
+	}
+
+	return( false );
+}
+
+//---------------------------------------------------------
+int CSG_Table::Get_Field_Length(int iField)	const
+{
+	int		Length	= 0;
+
+	if( iField >= 0 && iField < m_nFields && m_Field_Type[iField] == SG_DATATYPE_String )
+	{
+		for(int i=0; i<m_nRecords; i++)
+		{
+			const SG_Char	*s	= m_Records[i]->asString(iField);
+
+			if( s && s[0] )
+			{
+				int		n	= (int)SG_STR_LEN(s);
+
+				if( Length < n )
+				{
+					Length	= n;
+				}
+			}
+		}
+	}
+
+	return( Length );
+}
+
 
 ///////////////////////////////////////////////////////////
 //														 //
@@ -790,6 +898,28 @@ bool CSG_Table::_Del_Records(void)
 //														 //
 ///////////////////////////////////////////////////////////
 
+//---------------------------------------------------------
+void CSG_Table::Set_Modified(bool bModified)
+{
+	if( bModified != is_Modified() )
+	{
+		CSG_Data_Object::Set_Modified(bModified);
+
+		if( m_pOwner )
+		{
+			m_pOwner->Set_Modified(bModified);
+		}
+
+		if( bModified == false )
+		{
+			for(int iRecord=0; iRecord<Get_Count() && SG_UI_Process_Set_Progress(iRecord, Get_Count()); iRecord++)
+			{
+				Get_Record(iRecord)->Set_Modified(false);
+			}
+		}
+	}
+}
+
 //---------------------------------------------------------
 bool CSG_Table::Set_Value(int iRecord, int iField, const SG_Char  *Value)
 {
@@ -888,7 +1018,10 @@ bool CSG_Table::_Stats_Update(int iField) const
 
 			for(int iRecord=0; iRecord<m_nRecords; iRecord++, ppRecord++)
 			{
-				m_Field_Stats[iField]->Add_Value((*ppRecord)->asDouble(iField));
+				if( !(*ppRecord)->is_NoData(iField) )
+				{
+					m_Field_Stats[iField]->Add_Value((*ppRecord)->asDouble(iField));
+				}
 			}
 		}
 
