@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: saga_frame.h 911 2011-02-14 16:38:15Z reklov_w $
+ * Version $Id: saga_frame.h 1119 2011-06-29 12:13:43Z oconrad $
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -123,6 +123,8 @@ public:
 	void						On_WKSP_Show_UI				(wxUpdateUIEvent &event);
 	void						On_Active_Show				(wxCommandEvent  &event);
 	void						On_Active_Show_UI			(wxUpdateUIEvent &event);
+	void						On_Data_Source_Show			(wxCommandEvent  &event);
+	void						On_Data_Source_Show_UI		(wxUpdateUIEvent &event);
 	void						On_INFO_Show				(wxCommandEvent  &event);
 	void						On_INFO_Show_UI				(wxUpdateUIEvent &event);
 
@@ -181,10 +183,12 @@ private:
 
 	class CINFO					*m_pINFO;
 
-	class CWKSP					*m_pWKSP;
+	class CData_Source			*m_pData_Source;
 
 	class CACTIVE				*m_pActive;
 
+	class CWKSP					*m_pWKSP;
+
 	class wxAuiManager			*m_pLayout;
 
 
