@@ -1,3 +1,6 @@
+/**********************************************************
+ * Version $Id: view_table.h 911 2011-02-14 16:38:15Z reklov_w $
+ *********************************************************/
 
 ///////////////////////////////////////////////////////////
 //                                                       //
@@ -107,6 +110,8 @@ public:
 	void							On_Record_Del_UI	(wxUpdateUIEvent &event);
 	void							On_Record_Clr		(wxCommandEvent  &event);
 	void							On_Record_Clr_UI	(wxUpdateUIEvent &event);
+	void							On_Sel_To_Top		(wxCommandEvent  &event);
+	void							On_Sel_To_Top_UI	(wxUpdateUIEvent &event);
 
 	void							Update_Table		(void);
 	void							Update_Selection	(void);
