@@ -1,3 +1,6 @@
+/**********************************************************
+ * Version $Id: wksp_base_control.cpp 1074 2011-05-31 15:04:56Z oconrad $
+ *********************************************************/
 	
 ///////////////////////////////////////////////////////////
 //                                                       //
@@ -223,6 +226,14 @@ void CWKSP_Base_Control::On_Command(wxCommandEvent &event)
 		return;
 	}
 
+	//-----------------------------------------------------
+	if( event.GetId() == ID_CMD_WKSP_ITEM_SEARCH )
+	{
+		_Search_Item();
+
+		return;
+	}
+
 	//-----------------------------------------------------
 	if( m_pManager->On_Command(event.GetId()) )
 	{
@@ -292,10 +303,17 @@ bool CWKSP_Base_Control::_Add_Item(CWKSP_Base_Item *pItem, int Image, int selIma
 bool CWKSP_Base_Control::_Del_Item(CWKSP_Base_Item *pItem, bool bSilent)
 {
 	//-----------------------------------------------------
-	if( (	pItem == NULL	)
-	||	(	pItem->Get_Type()	== WKSP_ITEM_Table
-		&&	(	((CWKSP_Table *)pItem)->Get_Owner()->Get_Type() == WKSP_ITEM_Shapes
-			||	((CWKSP_Table *)pItem)->Get_Owner()->Get_Type() == WKSP_ITEM_TIN	)	)	)
+	if( pItem == NULL || pItem->GetId().IsOk() == false || pItem->Get_Control() != this )
+	{
+		return( false );
+	}
+
+	if( pItem->Get_Type() == WKSP_ITEM_Table &&	(((CWKSP_Table *)pItem)->Get_Owner()->Get_Type() == WKSP_ITEM_Shapes ||	((CWKSP_Table *)pItem)->Get_Owner()->Get_Type() == WKSP_ITEM_TIN) )
+	{
+		return( false );
+	}
+
+	if( !bSilent && !_Del_Item_Confirm(pItem) )
 	{
 		return( false );
 	}
@@ -303,14 +321,21 @@ bool CWKSP_Base_Control::_Del_Item(CWKSP_Base_Item *pItem, bool bSilent)
 	//-----------------------------------------------------
 	if( pItem == m_pManager )
 	{
-		if( m_pManager->Get_Count() > 0 && (bSilent || _Del_Item_Confirm(pItem)) )
+		if( m_pManager->Get_Count() > 0 )
 		{
 			Freeze();
+
 			if( g_pData_Buttons )
 			{
 				g_pData_Buttons->Freeze();
 			}
 
+			if( g_pMap_Buttons )
+			{
+				g_pMap_Buttons->Freeze();
+			}
+
+			//---------------------------------------------
 			DeleteChildren	(m_pManager->GetId());
 			AppendItem		(m_pManager->GetId(), LNG("[CAP] [no items]"), 0, 0, NULL);
 			Expand			(m_pManager->GetId());
@@ -320,6 +345,7 @@ bool CWKSP_Base_Control::_Del_Item(CWKSP_Base_Item *pItem, bool bSilent)
 				g_pModules->Get_Modules_Menu()->Update();
 			}
 
+			//---------------------------------------------
 			Thaw();
 
 			if( g_pData_Buttons )
@@ -330,6 +356,7 @@ bool CWKSP_Base_Control::_Del_Item(CWKSP_Base_Item *pItem, bool bSilent)
 
 			if( g_pMap_Buttons )
 			{
+				g_pMap_Buttons->Thaw();
 				g_pMap_Buttons->Update_Buttons();
 			}
 
@@ -340,45 +367,16 @@ bool CWKSP_Base_Control::_Del_Item(CWKSP_Base_Item *pItem, bool bSilent)
 	//-----------------------------------------------------
 	else
 	{
-		if( bSilent || _Del_Item_Confirm(pItem) )
+		CWKSP_Base_Manager	*pItem_Manager	= pItem->Get_Manager();
+
+		Freeze();
+
+		Delete(pItem->GetId());
+
+		if( pItem_Manager != NULL && pItem_Manager->Get_Count() == 0 )
 		{
-			CWKSP_Base_Manager	*pItem_Manager	= pItem->Get_Manager();
-
-			Freeze();
-
-			Delete(pItem->GetId());
-
-			if( pItem_Manager != NULL && pItem_Manager->Get_Count() == 0 )
-			{
-				Thaw();
-
-				if( m_pManager->Get_Type() == WKSP_ITEM_Data_Manager )
-				{
-					g_pData_Buttons->Update_Buttons();
-				}
-
-				if( m_pManager->Get_Type() == WKSP_ITEM_Map_Manager )
-				{
-					g_pMap_Buttons->Update_Buttons();
-				}
-
-				return( _Del_Item(pItem_Manager, true) );
-			}
-
-			if( m_pManager->Get_Type() == WKSP_ITEM_Module_Manager )
-			{
-				g_pModules->Get_Modules_Menu()->Update();
-			}
-
-			if( pItem_Manager != NULL && pItem_Manager->Get_Type() == WKSP_ITEM_Map )
-			{
-				((CWKSP_Map *)pItem_Manager)->View_Refresh(false);
-			}
-
 			Thaw();
 
-			Refresh();
-
 			if( m_pManager->Get_Type() == WKSP_ITEM_Data_Manager )
 			{
 				g_pData_Buttons->Update_Buttons();
@@ -389,8 +387,34 @@ bool CWKSP_Base_Control::_Del_Item(CWKSP_Base_Item *pItem, bool bSilent)
 				g_pMap_Buttons->Update_Buttons();
 			}
 
-			return( true );
+			return( _Del_Item(pItem_Manager, true) );
 		}
+
+		if( m_pManager->Get_Type() == WKSP_ITEM_Module_Manager )
+		{
+			g_pModules->Get_Modules_Menu()->Update();
+		}
+
+		if( pItem_Manager != NULL && pItem_Manager->Get_Type() == WKSP_ITEM_Map )
+		{
+			((CWKSP_Map *)pItem_Manager)->View_Refresh(false);
+		}
+
+		Thaw();
+
+		Refresh();
+
+		if( m_pManager->Get_Type() == WKSP_ITEM_Data_Manager )
+		{
+			g_pData_Buttons->Update_Buttons();
+		}
+
+		if( m_pManager->Get_Type() == WKSP_ITEM_Map_Manager )
+		{
+			g_pMap_Buttons->Update_Buttons();
+		}
+
+		return( true );
 	}
 
 	//-----------------------------------------------------
@@ -548,32 +572,31 @@ bool CWKSP_Base_Control::_Set_Active(void)
 //---------------------------------------------------------
 bool CWKSP_Base_Control::_Del_Active(bool bSilent)
 {
-	wxTreeItemId	ID;
-
 	if( GetWindowStyle() & wxTR_MULTIPLE )
 	{
 		wxArrayTreeItemIds	IDs;
 
-		if( GetSelections(IDs) > 0 && ((CWKSP_Base_Item *)GetItemData(IDs[0]))->Get_Control() == this )
+		if( GetSelections(IDs) > 0 && (bSilent || DLG_Message_Confirm(ID_DLG_DELETE)) && (m_pManager->Get_Type() != WKSP_ITEM_Data_Manager || g_pData->Save_Modified_Sel()) )
 		{
-			if( DLG_Message_Confirm(ID_DLG_DELETE)
-			&&	(m_pManager->Get_Type() != WKSP_ITEM_Data_Manager || g_pData->Save_Modified_Sel()) )
+			UnselectAll();
+
+			for(size_t i=0; i<IDs.GetCount(); i++)
 			{
-				for(size_t i=0; i<IDs.GetCount(); i++)
+				if( IDs[i].IsOk() )
 				{
-					if( IDs[i].IsOk() )
-					{
-						_Del_Item((CWKSP_Base_Item *)GetItemData(IDs[i]), true);
-					}
+					_Del_Item((CWKSP_Base_Item *)GetItemData(IDs[i]), true);
 				}
 			}
+
+			SelectItem(GetRootItem());
+			SetFocus();
 		}
 	}
 	else
 	{
-		ID	= GetSelection();
+		wxTreeItemId	ID	= GetSelection();
 
-		if( ID.IsOk() && ((CWKSP_Base_Item *)GetItemData(ID))->Get_Control() == this )
+		if( ID.IsOk() )
 		{
 			_Del_Item((CWKSP_Base_Item *)GetItemData(ID), bSilent);
 		}
@@ -736,6 +759,7 @@ CSG_Parameters *	DLG_Copy_Settings(void)
 	DLG_Copy_Settings(List, (CWKSP_Base_Item *)g_pData->Get_Grids());
 	DLG_Copy_Settings(List, (CWKSP_Base_Item *)g_pData->Get_Shapes());
 	DLG_Copy_Settings(List, (CWKSP_Base_Item *)g_pData->Get_TINs());
+	DLG_Copy_Settings(List, (CWKSP_Base_Item *)g_pData->Get_PointClouds());
 
 	if( List.Get_Count() > 0 )
 	{
@@ -773,24 +797,28 @@ bool CWKSP_Base_Control::_Copy_Settings(CSG_Parameters *pParameters, CWKSP_Base_
 {
 	if( pParameters && pItem && pParameters != pItem->Get_Parameters() )
 	{
-		CSG_String	sName;
-
-		if( pParameters->Get_Parameter("OBJECT_NAME") && pItem->Get_Parameters()->Get_Parameter("OBJECT_NAME") )
+		for(int i=0; i<pParameters->Get_Count(); i++)
 		{
-			sName	= pItem->Get_Parameters()->Get_Parameter("OBJECT_NAME")->asString();
-		}
+			CSG_Parameter	*pSource	= pParameters->Get_Parameter(i);
 
-		if( pItem->Get_Parameters()->Assign_Values(pParameters) )
-		{
-			if( sName.Length() > 0 && pItem->Get_Parameters()->Get_Parameter("OBJECT_NAME") )
+			if(	SG_STR_CMP(pSource->Get_Identifier(), SG_T("OBJECT_NAME")) )
+		//	&&	SG_STR_CMP(pSource->Get_Identifier(), SG_T("LUT_ATTRIB"))
+		//	&&	SG_STR_CMP(pSource->Get_Identifier(), SG_T("METRIC_ATTRIB"))
+		//	&&	SG_STR_CMP(pSource->Get_Identifier(), SG_T("LABEL_ATTRIB"))
+		//	&&	SG_STR_CMP(pSource->Get_Identifier(), SG_T("LABEL_ATTRIB_SIZE_BY"))	)
 			{
-				pItem->Get_Parameters()->Get_Parameter("OBJECT_NAME")->Set_Value(sName);
+				CSG_Parameter	*pTarget	= pItem->Get_Parameters()->Get_Parameter(pSource->Get_Identifier());
+
+				if( pTarget && pTarget->Get_Type() == pSource->Get_Type() )
+				{
+					pTarget->Set_Value(pSource);
+				}
 			}
-
-			pItem->Parameters_Changed();
-
-			return( true );
 		}
+
+		pItem->Parameters_Changed();
+
+		return( true );
 	}
 
 	return( false );
@@ -823,6 +851,115 @@ bool CWKSP_Base_Control::_Copy_Settings(void)
 }
 
 
+///////////////////////////////////////////////////////////
+//														 //
+//														 //
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+bool CWKSP_Base_Control::_Search_Compare(wxString A, wxString B, bool bCase)
+{
+	return( bCase ? B.Find(A) != wxNOT_FOUND : B.MakeUpper().Find(A.MakeUpper().c_str()) != wxNOT_FOUND );
+}
+
+//---------------------------------------------------------
+bool CWKSP_Base_Control::_Search_Get_List(CSG_Table *pList, CWKSP_Base_Item *pItem, const wxChar *String, bool bName, bool bDesc, bool bCase)
+{
+	if( pItem == NULL )
+	{
+		return( false );
+	}
+
+	if(	(bName && _Search_Compare(String, pItem->Get_Name       (), bCase))
+	||	(bDesc && _Search_Compare(String, pItem->Get_Description(), bCase)) )
+	{
+		CSG_Table_Record	*pRecord	= pList->Add_Record();
+
+		pRecord->Set_Value(0, pItem->Get_Name().c_str());
+		pRecord->Set_Value(1, pItem->Get_Type_Name(pItem->Get_Type()).c_str());
+		pRecord->Set_Value(2, (long)pItem);
+	}
+
+	if( pItem->is_Manager() )
+	{
+		for(int i=0; i<((CWKSP_Base_Manager *)pItem)->Get_Count(); i++)
+		{
+			_Search_Get_List(pList, ((CWKSP_Base_Manager *)pItem)->Get_Item(i), String, bName, bDesc, bCase);
+		}
+	}
+
+	return( true );
+}
+
+//---------------------------------------------------------
+bool CWKSP_Base_Control::_Search_Item(void)
+{
+	static CSG_Parameters	Search(NULL, LNG("Search for..."), LNG(""));
+
+	if( Search.Get_Count() == 0 )
+	{
+		Search.Add_String	(NULL, "STRING"	, LNG("Search for...")	, LNG(""), SG_T(""));
+		Search.Add_Value	(NULL, "NAME"	, LNG("Name")			, LNG(""), PARAMETER_TYPE_Bool, true);
+		Search.Add_Value	(NULL, "DESC"	, LNG("Description")	, LNG(""), PARAMETER_TYPE_Bool, false);
+		Search.Add_Value	(NULL, "CASE"	, LNG("Case Sensitive")	, LNG(""), PARAMETER_TYPE_Bool, false);
+	}
+
+	if( !DLG_Parameters(&Search) )
+	{
+		return( false );
+	}
+
+	//-----------------------------------------------------
+	CSG_Table	List;
+
+	List.Add_Field(LNG("NAME")	, SG_DATATYPE_String);
+	List.Add_Field(LNG("TYPE")	, SG_DATATYPE_String);
+	List.Add_Field(LNG("ADDR")	, SG_DATATYPE_Long);
+
+	_Search_Get_List(&List, m_pManager, Search("STRING")->asString(), Search("NAME")->asBool(), Search("DESC")->asBool(), Search("CASE")->asBool());
+
+	if( List.Get_Count() <= 0 )
+	{
+		wxMessageBox(LNG("Search text not found"), LNG("Search for..."), wxOK|wxICON_EXCLAMATION);
+
+		return( false );
+	}
+
+	//-----------------------------------------------------
+	wxString	*pItems	= new wxString[List.Get_Count()];
+
+	for(int i=0; i<List.Get_Count(); i++)
+	{
+		pItems[i].Printf(wxT("[%s] %s"), List[i].asString(1), List[i].asString(0));
+	}
+
+	wxSingleChoiceDialog	dlg(MDI_Get_Top_Window(),
+		LNG("Locate..."),
+		wxString::Format(wxT("%s: %s"), LNG("Search Text"), Search("STRING")->asString()),
+		List.Get_Count(), pItems
+	);
+
+	if( dlg.ShowModal() != wxID_OK )
+	{
+		delete[](pItems);
+
+		return( false );
+	}
+
+	delete[](pItems);
+
+	//-----------------------------------------------------
+	CWKSP_Base_Item	*pItem	= (CWKSP_Base_Item *)List.Get_Record(dlg.GetSelection())->asInt(2);
+
+	EnsureVisible	(pItem->GetId());
+	SelectItem		(pItem->GetId());
+	ScrollTo		(pItem->GetId());
+
+	return( true );
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 //														 //
