@@ -1,3 +1,6 @@
+/**********************************************************
+ * Version $Id: wksp_module.cpp 1003 2011-04-19 10:21:49Z oconrad $
+ *********************************************************/
 
 ///////////////////////////////////////////////////////////
 //                                                       //
@@ -184,124 +187,129 @@ void CWKSP_Module::Set_File_Name(const wxString &File_Name)
 //---------------------------------------------------------
 wxString CWKSP_Module::Get_Description(void)
 {
-	bool		bFirst, bOptionals	= false;
-	int			i;
-	CSG_Parameter	*pParameter;
-	wxString	s, sTmp;
+	wxString	s;
 
 	//-----------------------------------------------------
-	s.Append(wxString::Format(wxT("%s: <b>%s</b>")	, LNG("Module"), m_pModule->Get_Name()));
-
-	if( m_pModule->is_Interactive() )
-	{
-		s.Append(wxString::Format(wxT("<br>- %s -")	, LNG("interactive execution")));
-	}
-
-	if( m_pModule->Get_Author() && *(m_pModule->Get_Author()) )
-	{
-		s.Append(wxString::Format(wxT("<br>%s")		, m_pModule->Get_Author()));
-	}
-
-	if( m_Menu_Path.Length() > 0 )
-	{
-		sTmp	= m_Menu_Path;
-		sTmp.Replace(wxT("|"), wxT(" <b>></b> "));
-		s.Append(wxString::Format(wxT("<br>%s: <i>%s</i>"), LNG("Menu"), sTmp.c_str()));
-	}
-
-	if( m_pModule->Get_Description() && *(m_pModule->Get_Description()) )
-	{
-		s.Append(wxString::Format(wxT("<hr><b>%s</b><br>%s"), LNG("Description"), m_pModule->Get_Description()));
-	}
+	wxString	sMenu(m_Menu_Path);	sMenu.Replace(wxT("|"), wxT(" <b>></b> "));
 
+	wxString	sType(m_pModule->is_Grid() ? LNG("Grid") : LNG("Base"));	if( m_pModule->is_Interactive() )	sType	+= LNG("Interactive");
 
 	//-----------------------------------------------------
-	s.Append(wxString::Format(wxT("<hr><b>%s</b><br>"), LNG("Parameters")));
-	s.Append(wxString::Format(wxT("<table border=\"1\" width=\"100%%\" valign=\"top\" cellpadding=\"5\" rules=\"all\"><tr><th>%s</th><th>%s</th><th>%s</th><th>%s</th><th>%s</th></tr>\n"),
-		LNG("Name"), LNG("Type"), LNG("Identifier"), LNG("Description"), LNG("Constraints")
-	));
+	s	+= wxString::Format(wxT("<b>%s</b>"), LNG("Module"));
 
-	for(i=0, bFirst=true; i<m_pModule->Get_Parameters()->Get_Count(); i++)
+	s	+= wxT("<table border=\"0\">");
+
+	DESC_ADD_STR(LNG("Name")		, m_pModule->Get_Name());
+	DESC_ADD_INT(LNG("ID")			, m_pModule->Get_ID());
+	DESC_ADD_STR(LNG("Author")		, m_pModule->Get_Author());
+	DESC_ADD_STR(LNG("Menu")		, sMenu.c_str());
+	DESC_ADD_STR(LNG("Type")		, sType.c_str());
+
+	s	+= wxT("</table><hr>");
+
+	//-----------------------------------------------------
+	s	+= wxString::Format(wxT("<b>%s</b><br>"), LNG("Description"));
+
+	wxString	sDesc;
+
+	if( g_pModules->Get_Parameters()->Get_Parameter("HELP_SOURCE")->asInt() == 1 )
 	{
-		pParameter	= m_pModule->Get_Parameters()->Get_Parameter(i);
+		sDesc	= Get_Online_Module_Description(((CWKSP_Module_Library *)Get_Manager())->Get_File_Name(), Get_Module()->Get_ID());
+	}
 
-		if( pParameter->is_Input() )
+	s	+= sDesc.Length() > 0 ? sDesc.c_str() : m_pModule->Get_Description();
+
+	//-----------------------------------------------------
+	if( 1 )
+	{
+		bool	bFirst, bOptionals	= false;
+		int		i;
+
+		s	+= wxString::Format(wxT("<hr><b>%s</b><br>"), LNG("Parameters"));
+		s	+= wxString::Format(wxT("<table border=\"1\" width=\"100%%\" valign=\"top\" cellpadding=\"5\" rules=\"all\"><tr><th>%s</th><th>%s</th><th>%s</th><th>%s</th><th>%s</th></tr>\n"),
+				LNG("Name"), LNG("Type"), LNG("Identifier"), LNG("Description"), LNG("Constraints")
+			);
+
+		for(i=0, bFirst=true; i<m_pModule->Get_Parameters()->Get_Count(); i++)
 		{
-			if( bFirst )
+			CSG_Parameter	*pParameter	= m_pModule->Get_Parameters()->Get_Parameter(i);
+
+			if( pParameter->is_Input() )
 			{
-				bFirst	= false;
-				s.Append(wxString::Format(wxT("<tr><th colspan=\"5\">%s</th></tr>"), LNG("Input")));
+				if( bFirst )
+				{
+					bFirst	= false;
+					s	+= wxString::Format(wxT("<tr><th colspan=\"5\">%s</th></tr>"), LNG("Input"));
+				}
+
+				s	+= wxString::Format(wxT("<tr><td>%s%s</td><td>%s</td><td>%s</td><td>%s</td><td>%s</td></tr>"),
+					pParameter->Get_Name(),
+					pParameter->is_Optional() ? wxT(" (*)") : wxT(" "),
+					pParameter->Get_Description(PARAMETER_DESCRIPTION_TYPE).c_str(),
+					pParameter->Get_Identifier(),
+					pParameter->Get_Description(),
+					pParameter->Get_Description(PARAMETER_DESCRIPTION_PROPERTIES).c_str()
+				);
 			}
-
-			s.Append(wxString::Format(wxT("<tr><td>%s%s</td><td>%s</td><td>%s</td><td>%s</td><td>%s</td></tr>"),
-				pParameter->Get_Name(),
-				pParameter->is_Optional() ? wxT(" (*)") : wxT(" "),
-				pParameter->Get_Description(PARAMETER_DESCRIPTION_TYPE).c_str(),
-				pParameter->Get_Identifier(),
-				pParameter->Get_Description(),
-				pParameter->Get_Description(PARAMETER_DESCRIPTION_PROPERTIES).c_str()
-			));
 		}
-	}
 
-	for(i=0, bFirst=true; i<m_pModule->Get_Parameters()->Get_Count(); i++)
-	{
-		pParameter	= m_pModule->Get_Parameters()->Get_Parameter(i);
-
-		if( pParameter->is_Output() )
+		for(i=0, bFirst=true; i<m_pModule->Get_Parameters()->Get_Count(); i++)
 		{
-			if( bFirst )
+			CSG_Parameter	*pParameter	= m_pModule->Get_Parameters()->Get_Parameter(i);
+
+			if( pParameter->is_Output() )
 			{
-				bFirst	= false;
-				s.Append(wxString::Format(wxT("<tr><th colspan=\"5\">%s</th></tr>"), LNG("Output")));
+				if( bFirst )
+				{
+					bFirst	= false;
+					s	+= wxString::Format(wxT("<tr><th colspan=\"5\">%s</th></tr>"), LNG("Output"));
+				}
+
+				s	+= wxString::Format(wxT("<tr><td>%s%s</td><td>%s</td><td>%s</td><td>%s</td><td>%s</td></tr>"),
+					pParameter->Get_Name(),
+					pParameter->is_Optional() ? wxT(" (*)") : wxT(""),
+					pParameter->Get_Description(PARAMETER_DESCRIPTION_TYPE).c_str(),
+					pParameter->Get_Identifier(),
+					pParameter->Get_Description(),
+					pParameter->Get_Description(PARAMETER_DESCRIPTION_PROPERTIES).c_str()
+				);
 			}
-
-			s.Append(wxString::Format(wxT("<tr><td>%s%s</td><td>%s</td><td>%s</td><td>%s</td><td>%s</td></tr>"),
-				pParameter->Get_Name(),
-				pParameter->is_Optional() ? wxT(" (*)") : wxT(""),
-				pParameter->Get_Description(PARAMETER_DESCRIPTION_TYPE).c_str(),
-				pParameter->Get_Identifier(),
-				pParameter->Get_Description(),
-				pParameter->Get_Description(PARAMETER_DESCRIPTION_PROPERTIES).c_str()
-			));
 		}
-	}
 
-	for(i=0, bFirst=true; i<m_pModule->Get_Parameters()->Get_Count(); i++)
-	{
-		pParameter	= m_pModule->Get_Parameters()->Get_Parameter(i);
-
-		if( pParameter->is_Option() && pParameter->Get_Type() != PARAMETER_TYPE_Grid_System )
+		for(i=0, bFirst=true; i<m_pModule->Get_Parameters()->Get_Count(); i++)
 		{
-			if( bFirst )
+			CSG_Parameter	*pParameter	= m_pModule->Get_Parameters()->Get_Parameter(i);
+
+			if( pParameter->is_Option() && pParameter->Get_Type() != PARAMETER_TYPE_Grid_System )
 			{
-				bFirst	= false;
-				s.Append(wxString::Format(wxT("<tr><th colspan=\"5\">%s</th></tr>"), LNG("Options")));
+				if( bFirst )
+				{
+					bFirst	= false;
+					s	+= wxString::Format(wxT("<tr><th colspan=\"5\">%s</th></tr>"), LNG("Options"));
+				}
+
+				s	+= wxString::Format(wxT("<tr><td>%s</td><td>%s</td><td>%s</td><td>%s</td><td>%s</td></tr>"),
+					pParameter->Get_Name(),
+					pParameter->Get_Description(PARAMETER_DESCRIPTION_TYPE).c_str(),
+					pParameter->Get_Identifier(),
+					pParameter->Get_Description(),
+					pParameter->Get_Description(PARAMETER_DESCRIPTION_PROPERTIES).c_str()
+				);
+			}
+			else if( pParameter->is_Optional() )
+			{
+				bOptionals	= true;
 			}
-
-			s.Append(wxString::Format(wxT("<tr><td>%s</td><td>%s</td><td>%s</td><td>%s</td><td>%s</td></tr>"),
-				pParameter->Get_Name(),
-				pParameter->Get_Description(PARAMETER_DESCRIPTION_TYPE).c_str(),
-				pParameter->Get_Identifier(),
-				pParameter->Get_Description(),
-				pParameter->Get_Description(PARAMETER_DESCRIPTION_PROPERTIES).c_str()
-			));
 		}
-		else if( pParameter->is_Optional() )
+
+		s	+= wxT("</table>");
+
+		if( bOptionals )
 		{
-			bOptionals	= true;
+			s	+= wxString::Format(wxT("(*) <i>%s</i>"), LNG("optional"));
 		}
 	}
 
-	s.Append(wxT("</table>"));
-
-	if( bOptionals )
-	{
-		s.Append(wxString::Format(wxT("(*) <i>%s</i>"), LNG("optional")));
-	}
-
-	s.Replace(wxT("\n"), wxT("<br>"));
-
 	return( s );
 }
 
@@ -699,7 +707,7 @@ bool CWKSP_Module::is_Executing(void)
 							MSG_Execution_Add(s, true, true);
 
 #define MSG_ADD2(b, s1, s2)	MSG_General_Add  (b ? s1 : s2, true, true, b ? SG_UI_MSG_STYLE_SUCCESS : SG_UI_MSG_STYLE_FAILURE);\
-							MSG_Execution_Add(b ? s1 : s2, true, true, b ? SG_UI_MSG_STYLE_SUCCESS : SG_UI_MSG_STYLE_FAILURE);
+								MSG_Execution_Add(b ? s1 : s2, true, true, b ? SG_UI_MSG_STYLE_SUCCESS : SG_UI_MSG_STYLE_FAILURE);
 
 //---------------------------------------------------------
 bool CWKSP_Module::Execute(bool bDialog)
@@ -713,22 +721,25 @@ bool CWKSP_Module::Execute(bool bDialog)
 		{
 			if( g_pModule->is_Executing() )
 			{
-				if( DLG_Message_Confirm(LNG("[MSG] Shall execution be stopped?"), LNG("[CAP] Module Execution")) )
+				if( !bDialog || DLG_Message_Confirm(LNG("[MSG] Shall execution be stopped?"), LNG("[CAP] Module Execution")) )
 				{
 					PROCESS_Set_Okay(false);
 				}
 			}
 			else if( m_pModule->is_Interactive() )
 			{
-				bResult		= ((CSG_Module_Interactive *)m_pModule)->Execute_Finish();
-				g_pModule	= NULL;
+				if( !bDialog || DLG_Message_Confirm(LNG("[MSG] Shall execution be stopped?"), LNG("[CAP] Module Execution")) )
+				{
+					bResult		= ((CSG_Module_Interactive *)m_pModule)->Execute_Finish();
+					g_pModule	= NULL;
 
-				PROCESS_Set_Okay(true);
+					PROCESS_Set_Okay(true);
 
-				MSG_ADD2(bResult,
-					LNG("[MSG] Interactive module execution has been stopped"),
-					LNG("[MSG] Interactive module execution failed")
-				);
+					MSG_ADD2(bResult,
+						LNG("[MSG] Interactive module execution has been stopped"),
+						LNG("[MSG] Interactive module execution failed")
+					);
+				}
 			}
 		}
 		else
@@ -748,6 +759,11 @@ bool CWKSP_Module::Execute(bool bDialog)
 
 			g_pData->Check_Parameters(m_pModule->Get_Parameters());
 
+			for(int i=0; i<m_pModule->Get_Parameters_Count(); i++)
+			{
+				g_pData->Check_Parameters(m_pModule->Get_Parameters(i));
+			}
+
 			MSG_General_Add_Line();
 			MSG_Execution_Add_Line();
 			MSG_ADD(wxString::Format(wxT("%s: %s"), LNG("[MSG] Executing module"), m_pModule->Get_Name()));
