@@ -1,3 +1,6 @@
+/**********************************************************
+ * Version $Id: wksp_table.cpp 1015 2011-04-27 10:19:23Z oconrad $
+ *********************************************************/
 
 ///////////////////////////////////////////////////////////
 //                                                       //
@@ -87,14 +90,18 @@ CWKSP_Table::CWKSP_Table(CSG_Table *pTable, CWKSP_Base_Item *pOwner)
 	m_pDiagram	= NULL;
 
 	//-----------------------------------------------------
-	m_Parameters.Create(this, LNG(""), LNG(""));
-	m_Parameters.Set_Callback_On_Parameter_Changed(&_On_Parameter_Changed);
+	On_Create_Parameters();
 
 	m_Parameters.Add_String(
 		m_Parameters("NODE_GENERAL")	, "NAME"			, LNG("[CAP] Name"),
 		LNG(""),
 		m_pTable->Get_Name()
 	);
+
+	m_Parameters.Add_Range(
+		m_Parameters("NODE_GENERAL")	, "GENERAL_NODATA"	, LNG("[CAP] No Data"),
+		LNG("")
+	);
 }
 
 //---------------------------------------------------------
@@ -123,7 +130,7 @@ CWKSP_Table::~CWKSP_Table(void)
 //---------------------------------------------------------
 wxString CWKSP_Table::Get_Name(void)
 {
-	return( m_pTable->Get_Name() );
+	return( wxString::Format(wxT("%02d. %s"), 1 + Get_ID(), m_pTable->Get_Name()) );
 }
 
 //---------------------------------------------------------
@@ -132,36 +139,23 @@ wxString CWKSP_Table::Get_Description(void)
 	wxString	s;
 
 	//-----------------------------------------------------
-	s.Append(wxString::Format(wxT("<b>%s</b><table border=\"0\">"),
-		LNG("[CAP] Shapes")
-	));
+	s	+= wxString::Format(wxT("<b>%s</b>"), LNG("[CAP] Table"));
 
-	s.Append(wxString::Format(wxT("<tr><td>%s</td><td>%s</td></tr>"),
-		LNG("[CAP] Name")					, m_pTable->Get_Name()
-	));
+	s	+= wxT("<table border=\"0\">");
 
-	s.Append(wxString::Format(wxT("<tr><td>%s</td><td>%s</td></tr>"),
-		LNG("[CAP] File")					, m_pTable->Get_File_Name()
-	));
+	DESC_ADD_STR(LNG("[CAP] Name")		, m_pTable->Get_Name());
+	DESC_ADD_STR(LNG("[CAP] File")		, m_pTable->Get_File_Name());
+	DESC_ADD_INT(LNG("[CAP] Fields")	, m_pTable->Get_Field_Count());
+	DESC_ADD_INT(LNG("[CAP] Records")	, m_pTable->Get_Record_Count());
 
-	s.Append(wxString::Format(wxT("<tr><td>%s</td><td>%d</td></tr>"),
-		LNG("[CAP] Fields")					, m_pTable->Get_Field_Count()
-	));
+	s	+= wxT("</table>");
 
-	s.Append(wxString::Format(wxT("<tr><td>%s</td><td>%d</td></tr>"),
-		LNG("[CAP] Records")				, m_pTable->Get_Record_Count()
-	));
-
-	s.Append(wxT("</table>"));
+	s	+= Get_TableInfo_asHTML(m_pTable);
 
 	//-----------------------------------------------------
-	s.Append(wxString::Format(wxT("<hr><b>%s</b>"), LNG("[CAP] Table Description")));
-	s.Append(Get_TableInfo_asHTML(m_pTable));
-
-	//-----------------------------------------------------
-//	s.Append(wxString::Format(wxT("<hr><b>%s</b><font size=\"-1\">"), LNG("[CAP] Data History")));
-//	s.Append(m_pTable->Get_History().Get_HTML());
-//	s.Append(wxString::Format(wxT("</font")));
+//	s	+= wxString::Format(wxT("<hr><b>%s</b><font size=\"-1\">"), LNG("[CAP] Data History"));
+//	s	+= m_pTable->Get_History().Get_HTML();
+//	s	+= wxString::Format(wxT("</font"));
 
 	//-----------------------------------------------------
 	return( s );
@@ -274,28 +268,20 @@ void CWKSP_Table::Parameters_Changed(void)
 {
 	m_pTable->Set_Name(m_Parameters("NAME")->asString());
 
+	m_pTable->Set_NoData_Value_Range(
+		m_Parameters("GENERAL_NODATA")->asRange()->Get_LoVal(),
+		m_Parameters("GENERAL_NODATA")->asRange()->Get_HiVal()
+	);
+
 	Update_Views();
 
 	CWKSP_Base_Item::Parameters_Changed();
 }
 
 //---------------------------------------------------------
-int CWKSP_Table::_On_Parameter_Changed(CSG_Parameter *pParameter)
+int CWKSP_Table::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pParameter, int Flags)
 {
-	if( pParameter && pParameter->Get_Owner() && pParameter->Get_Owner()->Get_Owner() )
-	{
-		return( ((CWKSP_Table *)pParameter->Get_Owner()->Get_Owner())->
-			On_Parameter_Changed(pParameter->Get_Owner(), pParameter)
-		);
-	}
-
-	return( 0 );
-}
-
-//---------------------------------------------------------
-int CWKSP_Table::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
-{
-	return( 1 );
+	return( CWKSP_Base_Item::On_Parameter_Changed(pParameters, pParameter, Flags) );
 }
 
 
@@ -352,6 +338,11 @@ bool CWKSP_Table::DataObject_Changed(CSG_Parameters *pParameters)
 
 	m_Parameters("NAME")->Set_Value(m_pTable->Get_Name());
 
+	m_Parameters("GENERAL_NODATA")->asRange()->Set_Range(
+		m_pTable->Get_NoData_Value(),
+		m_pTable->Get_NoData_hiValue()
+	);
+
 	//-----------------------------------------------------
 //	g_pACTIVE->Update(this, false);
 
